"""Tests for organizations API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_organizations(client: MerakiClient) -> None:
    """Test get_organizations endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organizations().collect()
    assert isinstance(result, list)


def test_get_organization(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization(organization_id=organization_id)


def test_get_organization_action_batches(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_action_batches endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_action_batches(organization_id=organization_id)


def test_get_organization_adaptive_policy_acls(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_adaptive_policy_acls endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_adaptive_policy_acls(organization_id=organization_id)


def test_get_organization_adaptive_policy_groups(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_adaptive_policy_groups endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_adaptive_policy_groups(
            organization_id=organization_id
        )


def test_get_organization_adaptive_policy_overview(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_adaptive_policy_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_adaptive_policy_overview(
            organization_id=organization_id
        )


def test_get_organization_adaptive_policy_policies(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_adaptive_policy_policies endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_adaptive_policy_policies(
            organization_id=organization_id
        )


def test_get_organization_adaptive_policy_settings(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_adaptive_policy_settings endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_adaptive_policy_settings(
            organization_id=organization_id
        )


def test_get_organization_admins(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_admins endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_admins(organization_id=organization_id)


def test_get_organization_alerts_profiles(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_alerts_profiles endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_alerts_profiles(organization_id=organization_id)


def test_get_organization_api_requests(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_api_requests endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_api_requests(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_api_requests_overview(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_api_requests_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_api_requests_overview(organization_id=organization_id)


def test_get_organization_api_requests_overview_response_codes_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_api_requests_overview_response_codes_by_interval endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_api_requests_overview_response_codes_by_interval(
            organization_id=organization_id
        )


def test_get_organization_assurance_alerts(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_assurance_alerts endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_assurance_alerts(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_assurance_alerts_overview(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_assurance_alerts_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_assurance_alerts_overview(
            organization_id=organization_id
        )


def test_get_organization_assurance_alerts_overview_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_assurance_alerts_overview_by_network endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_assurance_alerts_overview_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_assurance_alerts_overview_by_type(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_assurance_alerts_overview_by_type endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_assurance_alerts_overview_by_type(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_assurance_alerts_taxonomy_categories(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_assurance_alerts_taxonomy_categories endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_assurance_alerts_taxonomy_categories(
            organization_id=organization_id
        )


def test_get_organization_assurance_alerts_taxonomy_types(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_assurance_alerts_taxonomy_types endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_assurance_alerts_taxonomy_types(
            organization_id=organization_id
        )


def test_get_organization_branding_policies(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_branding_policies endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_branding_policies(organization_id=organization_id)


def test_get_organization_branding_policies_priorities(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_branding_policies_priorities endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_branding_policies_priorities(
            organization_id=organization_id
        )


def test_get_organization_clients_bandwidth_usage_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_clients_bandwidth_usage_history endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_clients_bandwidth_usage_history(
            organization_id=organization_id
        )


def test_get_organization_clients_overview(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_clients_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_clients_overview(organization_id=organization_id)


def test_get_organization_config_templates(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_config_templates endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_config_templates(organization_id=organization_id)


def test_get_organization_configuration_changes(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_configuration_changes endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_configuration_changes(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_devices endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_availabilities(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_availabilities endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_availabilities(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_availabilities_change_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_availabilities_change_history endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_availabilities_change_history(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_controller_migrations(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_controller_migrations endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_controller_migrations(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_overview_by_model(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_overview_by_model endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_devices_overview_by_model(
            organization_id=organization_id
        )


def test_get_organization_devices_packet_capture_captures(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_packet_capture_captures endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_packet_capture_captures(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_packet_capture_schedules(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_packet_capture_schedules endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_devices_packet_capture_schedules(
            organization_id=organization_id
        )


def test_get_organization_devices_power_modules_statuses_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_power_modules_statuses_by_device endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_power_modules_statuses_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_provisioning_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_provisioning_statuses endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_provisioning_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_statuses(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_devices_statuses endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_statuses_overview(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_statuses_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_devices_statuses_overview(
            organization_id=organization_id
        )


def test_get_organization_devices_system_memory_usage_history_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_system_memory_usage_history_by_interval endpoint."""
    with skip_on_unsupported():
        result = (
            client.organizations.get_organization_devices_system_memory_usage_history_by_interval(
                organization_id=organization_id
            ).collect()
        )
    assert isinstance(result, list)


def test_get_organization_devices_uplinks_addresses_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_uplinks_addresses_by_device endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_devices_uplinks_addresses_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_devices_uplinks_loss_and_latency(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_devices_uplinks_loss_and_latency endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_devices_uplinks_loss_and_latency(
            organization_id=organization_id
        )


def test_get_organization_early_access_features(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_early_access_features endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_early_access_features(organization_id=organization_id)


def test_get_organization_early_access_features_opt_ins(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_early_access_features_opt_ins endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_early_access_features_opt_ins(
            organization_id=organization_id
        )


def test_get_organization_firmware_upgrades(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_firmware_upgrades endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_firmware_upgrades(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_firmware_upgrades_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_firmware_upgrades_by_device endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_firmware_upgrades_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_floor_plans_auto_locate_devices(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_floor_plans_auto_locate_devices endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_floor_plans_auto_locate_devices(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_floor_plans_auto_locate_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_floor_plans_auto_locate_statuses endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_floor_plans_auto_locate_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_integrations_xdr_networks(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_integrations_xdr_networks endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_integrations_xdr_networks(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_inventory_devices(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_inventory_devices endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_inventory_devices(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_inventory_devices_eox_overview(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_inventory_devices_eox_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_inventory_devices_eox_overview(
            organization_id=organization_id
        )


def test_get_organization_inventory_device(
    client: MerakiClient, organization_id: str, device_serial: str
) -> None:
    """Test get_organization_inventory_device endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_inventory_device(
            organization_id=organization_id, serial=device_serial
        )


def test_get_organization_licenses(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_licenses endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_licenses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_licenses_overview(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_licenses_overview endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_licenses_overview(organization_id=organization_id)


def test_get_organization_login_security(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_login_security endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_login_security(organization_id=organization_id)


def test_get_organization_networks(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_networks endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_networks(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_network_moves(client: MerakiClient, organization_id: str) -> None:
    """Test get_network_moves endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_network_moves(organization_id=organization_id).collect()
    assert isinstance(result, list)


def test_get_organization_openapi_spec(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_openapi_spec endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_openapi_spec(organization_id=organization_id)


def test_get_organization_policy_objects(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_policy_objects endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_policy_objects(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_policy_objects_groups(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_policy_objects_groups endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_policy_objects_groups(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_saml(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_saml endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_saml(organization_id=organization_id)


def test_get_organization_saml_idps(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_saml_idps endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_saml_idps(organization_id=organization_id)


def test_get_organization_saml_roles(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_saml_roles endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_saml_roles(organization_id=organization_id)


def test_get_organization_snmp(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_snmp endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_snmp(organization_id=organization_id)


def test_get_organization_splash_themes(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_splash_themes endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_splash_themes(organization_id=organization_id)


def test_get_organization_summary_top_appliances_by_utilization(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_appliances_by_utilization endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_appliances_by_utilization(
            organization_id=organization_id
        )


def test_get_organization_summary_top_applications_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_applications_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_applications_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_applications_categories_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_applications_categories_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_applications_categories_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_clients_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_clients_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_clients_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_clients_manufacturers_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_clients_manufacturers_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_clients_manufacturers_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_devices_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_devices_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_devices_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_devices_models_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_devices_models_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_devices_models_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_networks_by_status(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_networks_by_status endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_summary_top_networks_by_status(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_summary_top_ssids_by_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_ssids_by_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_ssids_by_usage(
            organization_id=organization_id
        )


def test_get_organization_summary_top_switches_by_energy_usage(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_top_switches_by_energy_usage endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_summary_top_switches_by_energy_usage(
            organization_id=organization_id
        )


def test_get_organization_uplinks_statuses(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_uplinks_statuses endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_uplinks_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_webhooks_alert_types(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_webhooks_alert_types endpoint."""
    with skip_on_unsupported():
        client.organizations.get_organization_webhooks_alert_types(organization_id=organization_id)


def test_get_organization_webhooks_logs(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_webhooks_logs endpoint."""
    with skip_on_unsupported():
        result = client.organizations.get_organization_webhooks_logs(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
