"""Tests for camera API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_device_camera_analytics_live(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_analytics_live endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_analytics_live(serial=device_serial)


def test_get_device_camera_analytics_overview(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_analytics_overview endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_analytics_overview(serial=device_serial)


def test_get_device_camera_analytics_recent(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_analytics_recent endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_analytics_recent(serial=device_serial)


def test_get_device_camera_analytics_zones(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_analytics_zones endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_analytics_zones(serial=device_serial)


def test_get_device_camera_custom_analytics(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_custom_analytics endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_custom_analytics(serial=device_serial)


def test_get_device_camera_quality_and_retention(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_quality_and_retention endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_quality_and_retention(serial=device_serial)


def test_get_device_camera_sense(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_sense endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_sense(serial=device_serial)


def test_get_device_camera_sense_object_detection_models(
    client: MerakiClient, device_serial: str
) -> None:
    """Test get_device_camera_sense_object_detection_models endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_sense_object_detection_models(serial=device_serial)


def test_get_device_camera_video_settings(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_video_settings endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_video_settings(serial=device_serial)


def test_get_device_camera_video_link(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_video_link endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_video_link(serial=device_serial)


def test_get_device_camera_wireless_profiles(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_camera_wireless_profiles endpoint."""
    with skip_on_unsupported():
        client.camera.get_device_camera_wireless_profiles(serial=device_serial)


def test_get_network_camera_quality_retention_profiles(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_camera_quality_retention_profiles endpoint."""
    with skip_on_unsupported():
        client.camera.get_network_camera_quality_retention_profiles(network_id=network_id)


def test_get_network_camera_schedules(client: MerakiClient, network_id: str) -> None:
    """Test get_network_camera_schedules endpoint."""
    with skip_on_unsupported():
        client.camera.get_network_camera_schedules(network_id=network_id)


def test_get_network_camera_wireless_profiles(client: MerakiClient, network_id: str) -> None:
    """Test get_network_camera_wireless_profiles endpoint."""
    with skip_on_unsupported():
        client.camera.get_network_camera_wireless_profiles(network_id=network_id)


def test_get_organization_camera_boundaries_areas_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_camera_boundaries_areas_by_device endpoint."""
    with skip_on_unsupported():
        client.camera.get_organization_camera_boundaries_areas_by_device(
            organization_id=organization_id
        )


def test_get_organization_camera_boundaries_lines_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_camera_boundaries_lines_by_device endpoint."""
    with skip_on_unsupported():
        client.camera.get_organization_camera_boundaries_lines_by_device(
            organization_id=organization_id
        )


def test_get_organization_camera_custom_analytics_artifacts(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_camera_custom_analytics_artifacts endpoint."""
    with skip_on_unsupported():
        client.camera.get_organization_camera_custom_analytics_artifacts(
            organization_id=organization_id
        )


def test_get_organization_camera_onboarding_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_camera_onboarding_statuses endpoint."""
    with skip_on_unsupported():
        client.camera.get_organization_camera_onboarding_statuses(organization_id=organization_id)


def test_get_organization_camera_permissions(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_camera_permissions endpoint."""
    with skip_on_unsupported():
        client.camera.get_organization_camera_permissions(organization_id=organization_id)


def test_get_organization_camera_roles(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_camera_roles endpoint."""
    with skip_on_unsupported():
        client.camera.get_organization_camera_roles(organization_id=organization_id)
