"""Tests for sensor API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_device_sensor_commands(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_sensor_commands endpoint."""
    with skip_on_unsupported():
        result = client.sensor.get_device_sensor_commands(serial=device_serial).collect()
    assert isinstance(result, list)


def test_get_device_sensor_relationships(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_sensor_relationships endpoint."""
    with skip_on_unsupported():
        client.sensor.get_device_sensor_relationships(serial=device_serial)


def test_get_network_sensor_alerts_current_overview_by_metric(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_sensor_alerts_current_overview_by_metric endpoint."""
    with skip_on_unsupported():
        client.sensor.get_network_sensor_alerts_current_overview_by_metric(network_id=network_id)


def test_get_network_sensor_alerts_overview_by_metric(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_sensor_alerts_overview_by_metric endpoint."""
    with skip_on_unsupported():
        client.sensor.get_network_sensor_alerts_overview_by_metric(network_id=network_id)


def test_get_network_sensor_alerts_profiles(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sensor_alerts_profiles endpoint."""
    with skip_on_unsupported():
        client.sensor.get_network_sensor_alerts_profiles(network_id=network_id)


def test_get_network_sensor_mqtt_brokers(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sensor_mqtt_brokers endpoint."""
    with skip_on_unsupported():
        client.sensor.get_network_sensor_mqtt_brokers(network_id=network_id)


def test_get_network_sensor_relationships(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sensor_relationships endpoint."""
    with skip_on_unsupported():
        client.sensor.get_network_sensor_relationships(network_id=network_id)


def test_get_organization_sensor_gateways_connections_latest(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_sensor_gateways_connections_latest endpoint."""
    with skip_on_unsupported():
        result = client.sensor.get_organization_sensor_gateways_connections_latest(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_sensor_readings_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_sensor_readings_history endpoint."""
    with skip_on_unsupported():
        result = client.sensor.get_organization_sensor_readings_history(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_sensor_readings_latest(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_sensor_readings_latest endpoint."""
    with skip_on_unsupported():
        result = client.sensor.get_organization_sensor_readings_latest(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
