"""Tests for switch API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_device_switch_ports(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_switch_ports endpoint."""
    with skip_on_unsupported():
        client.switch.get_device_switch_ports(serial=device_serial)


def test_get_device_switch_ports_statuses(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_switch_ports_statuses endpoint."""
    with skip_on_unsupported():
        client.switch.get_device_switch_ports_statuses(serial=device_serial)


def test_get_device_switch_ports_statuses_packets(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_switch_ports_statuses_packets endpoint."""
    with skip_on_unsupported():
        client.switch.get_device_switch_ports_statuses_packets(serial=device_serial)


def test_get_device_switch_routing_interfaces(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_switch_routing_interfaces endpoint."""
    with skip_on_unsupported():
        client.switch.get_device_switch_routing_interfaces(serial=device_serial)


def test_get_device_switch_routing_static_routes(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_switch_routing_static_routes endpoint."""
    with skip_on_unsupported():
        client.switch.get_device_switch_routing_static_routes(serial=device_serial)


def test_get_device_switch_warm_spare(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_switch_warm_spare endpoint."""
    with skip_on_unsupported():
        client.switch.get_device_switch_warm_spare(serial=device_serial)


def test_get_network_switch_access_control_lists(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_access_control_lists endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_access_control_lists(network_id=network_id)


def test_get_network_switch_access_policies(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_access_policies endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_access_policies(network_id=network_id)


def test_get_network_switch_alternate_management_interface(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_switch_alternate_management_interface endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_alternate_management_interface(network_id=network_id)


def test_get_network_switch_dhcp_v4_servers_seen(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_dhcp_v4_servers_seen endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_network_switch_dhcp_v4_servers_seen(
            network_id=network_id
        ).collect()
    assert isinstance(result, list)


def test_get_network_switch_dhcp_server_policy(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_dhcp_server_policy endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_dhcp_server_policy(network_id=network_id)


def test_get_network_switch_dhcp_server_policy_arp_inspection_trusted_servers(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_switch_dhcp_server_policy_arp_inspection_trusted_servers endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_network_switch_dhcp_server_policy_arp_inspection_trusted_servers(
            network_id=network_id
        ).collect()
    assert isinstance(result, list)


def test_get_network_switch_dhcp_server_policy_arp_inspection_warnings_by_device(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_switch_dhcp_server_policy_arp_inspection_warnings_by_device endpoint."""
    with skip_on_unsupported():
        result = (
            client.switch.get_network_switch_dhcp_server_policy_arp_inspection_warnings_by_device(
                network_id=network_id
            ).collect()
        )
    assert isinstance(result, list)


def test_get_network_switch_dscp_to_cos_mappings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_dscp_to_cos_mappings endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_dscp_to_cos_mappings(network_id=network_id)


def test_get_network_switch_link_aggregations(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_link_aggregations endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_link_aggregations(network_id=network_id)


def test_get_network_switch_mtu(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_mtu endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_mtu(network_id=network_id)


def test_get_network_switch_port_schedules(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_port_schedules endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_port_schedules(network_id=network_id)


def test_get_network_switch_qos_rules(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_qos_rules endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_qos_rules(network_id=network_id)


def test_get_network_switch_qos_rules_order(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_qos_rules_order endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_qos_rules_order(network_id=network_id)


def test_get_network_switch_routing_multicast(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_routing_multicast endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_routing_multicast(network_id=network_id)


def test_get_network_switch_routing_multicast_rendezvous_points(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_switch_routing_multicast_rendezvous_points endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_routing_multicast_rendezvous_points(network_id=network_id)


def test_get_network_switch_routing_ospf(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_routing_ospf endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_routing_ospf(network_id=network_id)


def test_get_network_switch_settings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_settings endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_settings(network_id=network_id)


def test_get_network_switch_stacks(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_stacks endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_stacks(network_id=network_id)


def test_get_network_switch_storm_control(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_storm_control endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_storm_control(network_id=network_id)


def test_get_network_switch_stp(client: MerakiClient, network_id: str) -> None:
    """Test get_network_switch_stp endpoint."""
    with skip_on_unsupported():
        client.switch.get_network_switch_stp(network_id=network_id)


def test_get_organization_summary_switch_power_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_summary_switch_power_history endpoint."""
    with skip_on_unsupported():
        client.switch.get_organization_summary_switch_power_history(organization_id=organization_id)


def test_get_organization_switch_ports_by_switch(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_switch_ports_by_switch endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_organization_switch_ports_by_switch(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_switch_ports_clients_overview_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_switch_ports_clients_overview_by_device endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_organization_switch_ports_clients_overview_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_switch_ports_overview(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_switch_ports_overview endpoint."""
    with skip_on_unsupported():
        client.switch.get_organization_switch_ports_overview(organization_id=organization_id)


def test_get_organization_switch_ports_statuses_by_switch(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_switch_ports_statuses_by_switch endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_organization_switch_ports_statuses_by_switch(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_switch_ports_topology_discovery_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_switch_ports_topology_discovery_by_device endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_organization_switch_ports_topology_discovery_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_switch_ports_usage_history_by_device_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_switch_ports_usage_history_by_device_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.switch.get_organization_switch_ports_usage_history_by_device_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
