"""Response schemas for spaces endpoints.

This module is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from __future__ import annotations

from pydantic import Field

from meraki_client.schemas._base import _BaseSchema


class GetOrganizationSpacesIntegrateStatusResponse(_BaseSchema):
    """Response for getOrganizationSpacesIntegrateStatus operation."""

    status: bool | None = None
    states: list[str] = Field(default_factory=list)
    email: str | None = None
    account_name: str | None = Field(
        default=None, validation_alias="accountName", serialization_alias="accountName"
    )
    account_type: str | None = Field(
        default=None, validation_alias="accountType", serialization_alias="accountType"
    )


class RemoveOrganizationSpacesIntegrationResponse(_BaseSchema):
    """Response for removeOrganizationSpacesIntegration operation."""

    status: bool | None = None
    message: str | None = None
