"""Enum request parameter type aliases.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""
from __future__ import annotations

from typing import Literal, TypeAlias

__all__ = [
{% for alias_name, _alias_type in enum_type_aliases.items() %}
    "{{ alias_name }}",
{% endfor %}
]

{% for alias_name, alias_type in enum_type_aliases.items() %}
{{ alias_name }}: TypeAlias = {{ alias_type }}
{% endfor %}
