"""Tests for wireless API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_device_wireless_bluetooth_settings(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_wireless_bluetooth_settings endpoint."""
    with skip_on_unsupported():
        client.wireless.get_device_wireless_bluetooth_settings(serial=device_serial)


def test_get_device_wireless_electronic_shelf_label(
    client: MerakiClient, device_serial: str
) -> None:
    """Test get_device_wireless_electronic_shelf_label endpoint."""
    with skip_on_unsupported():
        client.wireless.get_device_wireless_electronic_shelf_label(serial=device_serial)


def test_get_device_wireless_radio_settings(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_wireless_radio_settings endpoint."""
    with skip_on_unsupported():
        client.wireless.get_device_wireless_radio_settings(serial=device_serial)


def test_get_device_wireless_status(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_wireless_status endpoint."""
    with skip_on_unsupported():
        client.wireless.get_device_wireless_status(serial=device_serial)


def test_get_network_wireless_air_marshal(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_air_marshal endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_air_marshal(network_id=network_id)


def test_get_network_wireless_alternate_management_interface(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_wireless_alternate_management_interface endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_alternate_management_interface(network_id=network_id)


def test_get_network_wireless_billing(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_billing endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_billing(network_id=network_id)


def test_get_network_wireless_bluetooth_settings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_bluetooth_settings endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_bluetooth_settings(network_id=network_id)


def test_get_network_wireless_client_count_history(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_client_count_history endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_client_count_history(network_id=network_id)


def test_get_network_wireless_data_rate_history(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_data_rate_history endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_data_rate_history(network_id=network_id)


def test_get_network_wireless_electronic_shelf_label(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_electronic_shelf_label endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_electronic_shelf_label(network_id=network_id)


def test_get_network_wireless_electronic_shelf_label_configured_devices(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_wireless_electronic_shelf_label_configured_devices endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_electronic_shelf_label_configured_devices(
            network_id=network_id
        )


def test_get_network_wireless_ethernet_ports_profiles(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_wireless_ethernet_ports_profiles endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_ethernet_ports_profiles(network_id=network_id)


def test_get_network_wireless_latency_history(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_latency_history endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_latency_history(network_id=network_id)


def test_get_network_wireless_mesh_statuses(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_mesh_statuses endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_network_wireless_mesh_statuses(network_id=network_id).collect()
    assert isinstance(result, list)


def test_get_network_wireless_rf_profiles(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_rf_profiles endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_rf_profiles(network_id=network_id)


def test_get_network_wireless_settings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_settings endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_settings(network_id=network_id)


def test_get_network_wireless_ssids(client: MerakiClient, network_id: str) -> None:
    """Test get_network_wireless_ssids endpoint."""
    with skip_on_unsupported():
        client.wireless.get_network_wireless_ssids(network_id=network_id)


def test_get_organization_wireless_air_marshal_rules(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_air_marshal_rules endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_air_marshal_rules(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_air_marshal_settings_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_air_marshal_settings_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_air_marshal_settings_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_clients_overview_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_clients_overview_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_clients_overview_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_channel_utilization_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_channel_utilization_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_channel_utilization_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_channel_utilization_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_channel_utilization_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_channel_utilization_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_channel_utilization_history_by_device_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_channel_utilization_history_by_device_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_channel_utilization_history_by_device_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_channel_utilization_history_by_network_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_channel_utilization_history_by_network_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_channel_utilization_history_by_network_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_ethernet_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_ethernet_statuses endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_ethernet_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_packet_loss_by_client(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_packet_loss_by_client endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_packet_loss_by_client(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_packet_loss_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_packet_loss_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_packet_loss_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_packet_loss_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_packet_loss_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_packet_loss_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_power_mode_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_power_mode_history endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_power_mode_history(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_radsec_certificates_authorities(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_radsec_certificates_authorities endpoint."""
    with skip_on_unsupported():
        client.wireless.get_organization_wireless_devices_radsec_certificates_authorities(
            organization_id=organization_id
        )


def test_get_organization_wireless_devices_radsec_certificates_authorities_crls(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_radsec_certificates_authorities_crls endpoint."""
    with skip_on_unsupported():
        client.wireless.get_organization_wireless_devices_radsec_certificates_authorities_crls(
            organization_id=organization_id
        )


def test_get_organization_wireless_devices_radsec_certificates_authorities_crls_deltas(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_radsec_certificates_authorities_crls_deltas endpoint."""
    with skip_on_unsupported():
        client.wireless.get_organization_wireless_devices_radsec_certificates_authorities_crls_deltas(
            organization_id=organization_id
        )


def test_get_organization_wireless_devices_system_cpu_load_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_system_cpu_load_history endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_system_cpu_load_history(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_devices_wireless_controllers_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_devices_wireless_controllers_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_devices_wireless_controllers_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_location_scanning_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_location_scanning_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_location_scanning_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_location_scanning_receivers(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_location_scanning_receivers endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_location_scanning_receivers(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_mqtt_settings(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_mqtt_settings endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_mqtt_settings(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_radio_rrm_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_radio_rrm_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_radio_rrm_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_rf_profiles_assignments_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_rf_profiles_assignments_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_rf_profiles_assignments_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_ssids_firewall_isolation_allowlist_entries(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_ssids_firewall_isolation_allowlist_entries endpoint."""
    with skip_on_unsupported():
        result = (
            client.wireless.get_organization_wireless_ssids_firewall_isolation_allowlist_entries(
                organization_id=organization_id
            ).collect()
        )
    assert isinstance(result, list)


def test_get_organization_wireless_ssids_open_roaming_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_ssids_open_roaming_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_ssids_open_roaming_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_ssids_statuses_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_ssids_statuses_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_ssids_statuses_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_zigbee_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_zigbee_by_network endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_zigbee_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_zigbee_devices(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_zigbee_devices endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_zigbee_devices(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_zigbee_door_locks(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_zigbee_door_locks endpoint."""
    with skip_on_unsupported():
        result = client.wireless.get_organization_wireless_zigbee_door_locks(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
