"""Tests for sm API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_network_sm_devices(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sm_devices endpoint."""
    with skip_on_unsupported():
        result = client.sm.get_network_sm_devices(network_id=network_id).collect()
    assert isinstance(result, list)


def test_get_network_sm_profiles(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sm_profiles endpoint."""
    with skip_on_unsupported():
        client.sm.get_network_sm_profiles(network_id=network_id)


def test_get_network_sm_target_groups(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sm_target_groups endpoint."""
    with skip_on_unsupported():
        client.sm.get_network_sm_target_groups(network_id=network_id)


def test_get_network_sm_trusted_access_configs(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sm_trusted_access_configs endpoint."""
    with skip_on_unsupported():
        result = client.sm.get_network_sm_trusted_access_configs(network_id=network_id).collect()
    assert isinstance(result, list)


def test_get_network_sm_user_access_devices(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sm_user_access_devices endpoint."""
    with skip_on_unsupported():
        result = client.sm.get_network_sm_user_access_devices(network_id=network_id).collect()
    assert isinstance(result, list)


def test_get_network_sm_users(client: MerakiClient, network_id: str) -> None:
    """Test get_network_sm_users endpoint."""
    with skip_on_unsupported():
        client.sm.get_network_sm_users(network_id=network_id)


def test_get_organization_sm_admins_roles(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_sm_admins_roles endpoint."""
    with skip_on_unsupported():
        result = client.sm.get_organization_sm_admins_roles(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_sm_apns_cert(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_sm_apns_cert endpoint."""
    with skip_on_unsupported():
        client.sm.get_organization_sm_apns_cert(organization_id=organization_id)


def test_get_organization_sm_sentry_policies_assignments_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_sm_sentry_policies_assignments_by_network endpoint."""
    with skip_on_unsupported():
        result = client.sm.get_organization_sm_sentry_policies_assignments_by_network(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_sm_vpp_accounts(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_sm_vpp_accounts endpoint."""
    with skip_on_unsupported():
        client.sm.get_organization_sm_vpp_accounts(organization_id=organization_id)
