"""Batch API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from meraki_client._api.batch.appliance import ActionBatchAppliance
from meraki_client._api.batch.camera import ActionBatchCamera
from meraki_client._api.batch.campus_gateway import ActionBatchCampusGateway
from meraki_client._api.batch.cellular_gateway import ActionBatchCellularGateway
from meraki_client._api.batch.devices import ActionBatchDevices
from meraki_client._api.batch.insight import ActionBatchInsight
from meraki_client._api.batch.networks import ActionBatchNetworks
from meraki_client._api.batch.organizations import ActionBatchOrganizations
from meraki_client._api.batch.sensor import ActionBatchSensor
from meraki_client._api.batch.sm import ActionBatchSm
from meraki_client._api.batch.spaces import ActionBatchSpaces
from meraki_client._api.batch.switch import ActionBatchSwitch
from meraki_client._api.batch.wireless import ActionBatchWireless


class Batch:
    """Batch class."""

    def __init__(self) -> None:
        self.appliance = ActionBatchAppliance()
        self.camera = ActionBatchCamera()
        self.campus_gateway = ActionBatchCampusGateway()
        self.cellular_gateway = ActionBatchCellularGateway()
        self.devices = ActionBatchDevices()
        self.insight = ActionBatchInsight()
        self.networks = ActionBatchNetworks()
        self.organizations = ActionBatchOrganizations()
        self.sensor = ActionBatchSensor()
        self.sm = ActionBatchSm()
        self.spaces = ActionBatchSpaces()
        self.switch = ActionBatchSwitch()
        self.wireless = ActionBatchWireless()
