"""Tests for wirelessController API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_organization_wireless_controller_availabilities_change_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_availabilities_change_history endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_availabilities_change_history(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_clients_overview_history_by_device_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_clients_overview_history_by_device_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_clients_overview_history_by_device_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_connections(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_connections endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_connections(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_l2_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_l2_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_l2_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_l2_statuses_change_history_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_l2_statuses_change_history_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_l2_statuses_change_history_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_l2_usage_history_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_l2_usage_history_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_l2_usage_history_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_l3_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_l3_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_l3_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_l3_statuses_change_history_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_l3_statuses_change_history_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_l3_statuses_change_history_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_l3_usage_history_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_l3_usage_history_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_l3_usage_history_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_packets_overview_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_packets_overview_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_packets_overview_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_interfaces_usage_history_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_interfaces_usage_history_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_interfaces_usage_history_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_redundancy_failover_history(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_redundancy_failover_history endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_redundancy_failover_history(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_redundancy_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_redundancy_statuses endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_redundancy_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_devices_system_utilization_history_by_interval(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_devices_system_utilization_history_by_interval endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_devices_system_utilization_history_by_interval(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_wireless_controller_overview_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_wireless_controller_overview_by_device endpoint."""
    with skip_on_unsupported():
        result = client.wireless_controller.get_organization_wireless_controller_overview_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
