"""Tests for spaces API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_organization_spaces_integrate_status(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_spaces_integrate_status endpoint."""
    with skip_on_unsupported():
        client.spaces.get_organization_spaces_integrate_status(organization_id=organization_id)
