"""{{ class_name }} API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""
{% set session_path = "aio._session" if is_async else "_session" %}
from __future__ import annotations

import urllib.parse
from typing import TYPE_CHECKING, Any, Literal

{% if enum_type_aliases %}
from meraki_client.types import (
{% for type_alias in enum_type_aliases %}
    {{ type_alias }},
{% endfor %}
)
{% endif %}

{% if schemas_used %}
from meraki_client.schemas import (
    DictResponse,
{% for schema in schemas_used %}
    {{ schema }},
{% endfor %}
)
{% endif %}

if TYPE_CHECKING:
    from meraki_client.{{ session_path }} import {% if is_async %}Async{% endif %}PaginatedResponse, Session


class {{ class_name }}:
    """{{ class_name }} class."""

    def __init__(self, session: Session) -> None:
        self._session = session

