"""Enum request parameter type aliases.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from __future__ import annotations

from typing import Literal, TypeAlias

__all__ = [
    "CreateDeviceSensorCommandOperation",
    "CreateDeviceSwitchRoutingInterfaceMode",
    "CreateDeviceSwitchRoutingInterfaceMulticastRouting",
    "CreateNetworkApplianceVlanDhcpHandling",
    "CreateNetworkApplianceVlanDhcpLeaseTime",
    "CreateNetworkApplianceVlanTemplateVlanType",
    "CreateNetworkFirmwareUpgradesRollbackProduct",
    "CreateNetworkGroupPolicySplashAuthSettings",
    "CreateNetworkMerakiAuthUserAccountType",
    "CreateNetworkPiiRequestType",
    "CreateNetworkSwitchAccessPolicyAccessPolicyType",
    "CreateNetworkSwitchAccessPolicyHostMode",
    "CreateNetworkSwitchQosRuleProtocol",
    "CreateNetworkSwitchStackRoutingInterfaceMode",
    "CreateNetworkSwitchStackRoutingInterfaceMulticastRouting",
    "CreateNetworkWirelessAirMarshalRuleType",
    "CreateNetworkWirelessRfProfileBandSelectionType",
    "CreateNetworkWirelessRfProfileMinBitrateType",
    "CreateOrganizationAdaptivePolicyAclIpVersion",
    "CreateOrganizationAdaptivePolicyPolicyLastEntryRule",
    "CreateOrganizationAdminAuthenticationMethod",
    "CreateOrganizationAdminOrgAccess",
    "CreateOrganizationAlertsProfileType",
    "CreateOrganizationDevicesControllerMigrationTarget",
    "CreateOrganizationNetworkProductTypes",
    "CreateOrganizationSmAdminsRoleScope",
    "GetAdministeredLicensingSubscriptionSubscriptionsProductTypes",
    "GetAdministeredLicensingSubscriptionSubscriptionsStatuses",
    "GetDeviceCameraAnalyticsOverviewObjectType",
    "GetDeviceCameraAnalyticsRecentObjectType",
    "GetDeviceCameraAnalyticsZoneHistoryObjectType",
    "GetDeviceLossAndLatencyHistoryUplink",
    "GetDeviceSensorCommandsSortOrder",
    "GetDeviceSwitchRoutingInterfacesMode",
    "GetDeviceSwitchRoutingInterfacesProtocol",
    "GetDeviceWirelessConnectionStatsBand",
    "GetDeviceWirelessConnectionStatsSsid",
    "GetDeviceWirelessLatencyStatsBand",
    "GetDeviceWirelessLatencyStatsSsid",
    "GetNetworkApplianceClientSecurityEventsSortOrder",
    "GetNetworkApplianceSecurityEventsSortOrder",
    "GetNetworkClientsApplicationUsageSsidNumber",
    "GetNetworkClientsRecentDeviceConnections",
    "GetNetworkClientsStatuses",
    "GetNetworkClientsUsageHistoriesSsidNumber",
    "GetNetworkEventsProductType",
    "GetNetworkSplashLoginAttemptsSsidNumber",
    "GetNetworkSwitchStackRoutingInterfacesMode",
    "GetNetworkSwitchStackRoutingInterfacesProtocol",
    "GetNetworkTrafficDeviceType",
    "GetNetworkVlanProfilesAssignmentsByDeviceProductTypes",
    "GetNetworkWirelessChannelUtilizationHistoryBand",
    "GetNetworkWirelessClientConnectionStatsBand",
    "GetNetworkWirelessClientConnectionStatsSsid",
    "GetNetworkWirelessClientConnectivityEventsBand",
    "GetNetworkWirelessClientConnectivityEventsIncludedSeverities",
    "GetNetworkWirelessClientConnectivityEventsSortOrder",
    "GetNetworkWirelessClientConnectivityEventsSsidNumber",
    "GetNetworkWirelessClientConnectivityEventsTypes",
    "GetNetworkWirelessClientCountHistoryBand",
    "GetNetworkWirelessClientLatencyStatsBand",
    "GetNetworkWirelessClientLatencyStatsSsid",
    "GetNetworkWirelessClientsConnectionStatsBand",
    "GetNetworkWirelessClientsConnectionStatsSsid",
    "GetNetworkWirelessClientsLatencyStatsBand",
    "GetNetworkWirelessClientsLatencyStatsSsid",
    "GetNetworkWirelessConnectionStatsBand",
    "GetNetworkWirelessConnectionStatsSsid",
    "GetNetworkWirelessDataRateHistoryBand",
    "GetNetworkWirelessDevicesConnectionStatsBand",
    "GetNetworkWirelessDevicesConnectionStatsSsid",
    "GetNetworkWirelessDevicesLatencyStatsBand",
    "GetNetworkWirelessDevicesLatencyStatsSsid",
    "GetNetworkWirelessFailedConnectionsBand",
    "GetNetworkWirelessFailedConnectionsSsid",
    "GetNetworkWirelessLatencyHistoryAccessCategory",
    "GetNetworkWirelessLatencyHistoryBand",
    "GetNetworkWirelessLatencyStatsBand",
    "GetNetworkWirelessLatencyStatsSsid",
    "GetNetworkWirelessSignalQualityHistoryBand",
    "GetNetworkWirelessUsageHistoryBand",
    "GetOrganizationActionBatchesStatus",
    "GetOrganizationApiRequestsMethod",
    "GetOrganizationApiRequestsOverviewResponseCodesByIntervalVersion",
    "GetOrganizationApiRequestsVersion",
    "GetOrganizationApplianceSecurityEventsSortOrder",
    "GetOrganizationAssuranceAlertsCategory",
    "GetOrganizationAssuranceAlertsDeviceTypes",
    "GetOrganizationAssuranceAlertsOverviewByNetworkCategory",
    "GetOrganizationAssuranceAlertsOverviewByNetworkDeviceTypes",
    "GetOrganizationAssuranceAlertsOverviewByNetworkSortOrder",
    "GetOrganizationAssuranceAlertsOverviewByNetworkTypes",
    "GetOrganizationAssuranceAlertsOverviewByTypeCategory",
    "GetOrganizationAssuranceAlertsOverviewByTypeDeviceTypes",
    "GetOrganizationAssuranceAlertsOverviewByTypeSortBy",
    "GetOrganizationAssuranceAlertsOverviewByTypeSortOrder",
    "GetOrganizationAssuranceAlertsOverviewByTypeTypes",
    "GetOrganizationAssuranceAlertsOverviewCategory",
    "GetOrganizationAssuranceAlertsOverviewDeviceTypes",
    "GetOrganizationAssuranceAlertsOverviewHistoricalCategory",
    "GetOrganizationAssuranceAlertsOverviewHistoricalDeviceTypes",
    "GetOrganizationAssuranceAlertsOverviewHistoricalTypes",
    "GetOrganizationAssuranceAlertsOverviewTypes",
    "GetOrganizationAssuranceAlertsSortBy",
    "GetOrganizationAssuranceAlertsSortOrder",
    "GetOrganizationAssuranceAlertsTypes",
    "GetOrganizationCameraDetectionsHistoryByBoundaryByIntervalBoundaryTypes",
    "GetOrganizationDevicesAvailabilitiesChangeHistoryStatuses",
    "GetOrganizationDevicesAvailabilitiesStatuses",
    "GetOrganizationDevicesAvailabilitiesTagsFilterType",
    "GetOrganizationDevicesControllerMigrationsTarget",
    "GetOrganizationDevicesOverviewByModelProductTypes",
    "GetOrganizationDevicesPacketCaptureCapturesSortOrder",
    "GetOrganizationDevicesPowerModulesStatusesByDeviceTagsFilterType",
    "GetOrganizationDevicesProductTypes",
    "GetOrganizationDevicesProvisioningStatusesStatus",
    "GetOrganizationDevicesProvisioningStatusesTagsFilterType",
    "GetOrganizationDevicesSensorMetrics",
    "GetOrganizationDevicesStatusesOverviewProductTypes",
    "GetOrganizationDevicesStatusesProductTypes",
    "GetOrganizationDevicesStatusesStatuses",
    "GetOrganizationDevicesStatusesTagsFilterType",
    "GetOrganizationDevicesSystemMemoryUsageHistoryByIntervalProductTypes",
    "GetOrganizationDevicesTagsFilterType",
    "GetOrganizationDevicesUplinksAddressesByDeviceTagsFilterType",
    "GetOrganizationDevicesUplinksLossAndLatencyUplink",
    "GetOrganizationFirmwareUpgradesByDeviceUpgradeStatuses",
    "GetOrganizationInventoryDevicesEoxStatuses",
    "GetOrganizationInventoryDevicesProductTypes",
    "GetOrganizationInventoryDevicesTagsFilterType",
    "GetOrganizationInventoryDevicesUsedState",
    "GetOrganizationInventoryOnboardingCloudMonitoringNetworksDeviceType",
    "GetOrganizationLicensesState",
    "GetOrganizationNetworksProductTypes",
    "GetOrganizationNetworksTagsFilterType",
    "GetOrganizationOpenapiSpecVersion",
    "GetOrganizationSensorReadingsHistoryMetrics",
    "GetOrganizationSensorReadingsLatestMetrics",
    "GetOrganizationWebhooksAlertTypesProductType",
    "GetOrganizationWirelessRadioRrmByNetworkSortOrder",
    "GetOrganizationWirelessRfProfilesAssignmentsByDeviceProductTypes",
    "GetOrganizationWirelessSsidsFirewallIsolationAllowlistEntriesSsids",
    "ProvisionNetworkClientsDevicePolicy",
    "UpdateDeviceCameraQualityAndRetentionMotionDetectorVersion",
    "UpdateDeviceCameraQualityAndRetentionQuality",
    "UpdateDeviceCameraQualityAndRetentionResolution",
    "UpdateDeviceSwitchPortAccessPolicyType",
    "UpdateDeviceSwitchPortStpGuard",
    "UpdateDeviceSwitchPortType",
    "UpdateDeviceSwitchPortUdld",
    "UpdateDeviceSwitchRoutingInterfaceDhcpDhcpLeaseTime",
    "UpdateDeviceSwitchRoutingInterfaceDhcpDhcpMode",
    "UpdateDeviceSwitchRoutingInterfaceDhcpDnsNameserversOption",
    "UpdateDeviceSwitchRoutingInterfaceMulticastRouting",
    "UpdateNetworkApplianceContentFilteringUrlCategoryListSize",
    "UpdateNetworkApplianceFirewallFirewalledServiceAccess",
    "UpdateNetworkApplianceSecurityIntrusionIdsRulesets",
    "UpdateNetworkApplianceSecurityIntrusionMode",
    "UpdateNetworkApplianceSecurityMalwareMode",
    "UpdateNetworkApplianceSettingsClientTrackingMethod",
    "UpdateNetworkApplianceSettingsDeploymentMode",
    "UpdateNetworkApplianceSsidAuthMode",
    "UpdateNetworkApplianceSsidEncryptionMode",
    "UpdateNetworkApplianceSsidWpaEncryptionMode",
    "UpdateNetworkApplianceVlanDhcpHandling",
    "UpdateNetworkApplianceVlanDhcpLeaseTime",
    "UpdateNetworkApplianceVlanTemplateVlanType",
    "UpdateNetworkApplianceVpnSiteToSiteVpnMode",
    "UpdateNetworkGroupPolicySplashAuthSettings",
    "UpdateNetworkSnmpAccess",
    "UpdateNetworkSwitchAccessPolicyAccessPolicyType",
    "UpdateNetworkSwitchAccessPolicyHostMode",
    "UpdateNetworkSwitchAlternateManagementInterfaceProtocols",
    "UpdateNetworkSwitchDhcpServerPolicyDefaultPolicy",
    "UpdateNetworkSwitchQosRuleProtocol",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpDhcpLeaseTime",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpDhcpMode",
    "UpdateNetworkSwitchStackRoutingInterfaceDhcpDnsNameserversOption",
    "UpdateNetworkSwitchStackRoutingInterfaceMulticastRouting",
    "UpdateNetworkTrafficAnalysisMode",
    "UpdateNetworkWirelessAirMarshalRuleType",
    "UpdateNetworkWirelessAirMarshalSettingsDefaultPolicy",
    "UpdateNetworkWirelessAlternateManagementInterfaceProtocols",
    "UpdateNetworkWirelessBluetoothSettingsMajorMinorAssignmentMode",
    "UpdateNetworkWirelessElectronicShelfLabelMode",
    "UpdateNetworkWirelessRfProfileBandSelectionType",
    "UpdateNetworkWirelessRfProfileMinBitrateType",
    "UpdateNetworkWirelessSettingsUpgradeStrategy",
    "UpdateNetworkWirelessSsidAuthMode",
    "UpdateNetworkWirelessSsidEncryptionMode",
    "UpdateNetworkWirelessSsidEnterpriseAdminAccess",
    "UpdateNetworkWirelessSsidHotspot20NetworkAccessType",
    "UpdateNetworkWirelessSsidRadiusAttributeForGroupPolicies",
    "UpdateNetworkWirelessSsidRadiusFailoverPolicy",
    "UpdateNetworkWirelessSsidRadiusLoadBalancingPolicy",
    "UpdateNetworkWirelessSsidSplashPage",
    "UpdateNetworkWirelessSsidSplashSettingsControllerDisconnectionBehavior",
    "UpdateNetworkWirelessSsidSplashSettingsSplashTimeout",
    "UpdateNetworkWirelessSsidWpaEncryptionMode",
    "UpdateOrganizationAdaptivePolicyAclIpVersion",
    "UpdateOrganizationAdaptivePolicyPolicyLastEntryRule",
    "UpdateOrganizationAdminOrgAccess",
    "UpdateOrganizationAlertsProfileType",
    "UpdateOrganizationConfigTemplateSwitchProfilePortAccessPolicyType",
    "UpdateOrganizationConfigTemplateSwitchProfilePortStpGuard",
    "UpdateOrganizationConfigTemplateSwitchProfilePortType",
    "UpdateOrganizationConfigTemplateSwitchProfilePortUdld",
    "UpdateOrganizationSmAdminsRoleScope",
    "UpdateOrganizationSnmpV3AuthMode",
    "UpdateOrganizationSnmpV3PrivMode",
    "VmxNetworkDevicesClaimSize",
]

CreateDeviceSensorCommandOperation: TypeAlias = Literal[
    "cycleDownstreamPower", "disableDownstreamPower", "enableDownstreamPower", "refreshData"
]
CreateDeviceSwitchRoutingInterfaceMode: TypeAlias = Literal[
    "loopback", "oob_management", "routed", "vlan"
]
CreateDeviceSwitchRoutingInterfaceMulticastRouting: TypeAlias = Literal[
    "IGMP snooping querier", "disabled", "enabled"
]
CreateNetworkApplianceVlanDhcpHandling: TypeAlias = Literal[
    "Do not respond to DHCP requests", "Relay DHCP to another server", "Run a DHCP server"
]
CreateNetworkApplianceVlanDhcpLeaseTime: TypeAlias = Literal[
    "1 day", "1 hour", "1 week", "12 hours", "30 minutes", "4 hours"
]
CreateNetworkApplianceVlanTemplateVlanType: TypeAlias = Literal["same", "unique"]
CreateNetworkFirmwareUpgradesRollbackProduct: TypeAlias = Literal[
    "appliance",
    "camera",
    "cellularGateway",
    "secureConnect",
    "switch",
    "switchCatalyst",
    "wireless",
    "wirelessController",
]
CreateNetworkGroupPolicySplashAuthSettings: TypeAlias = Literal["bypass", "network default"]
CreateNetworkMerakiAuthUserAccountType: TypeAlias = Literal["802.1X", "Client VPN", "Guest"]
CreateNetworkPiiRequestType: TypeAlias = Literal["delete", "restrict processing"]
CreateNetworkSwitchAccessPolicyAccessPolicyType: TypeAlias = Literal[
    "802.1x", "Hybrid authentication", "MAC authentication bypass"
]
CreateNetworkSwitchAccessPolicyHostMode: TypeAlias = Literal[
    "Multi-Auth", "Multi-Domain", "Multi-Host", "Single-Host"
]
CreateNetworkSwitchQosRuleProtocol: TypeAlias = Literal["ANY", "TCP", "UDP"]
CreateNetworkSwitchStackRoutingInterfaceMode: TypeAlias = Literal[
    "loopback", "oob_management", "routed", "vlan"
]
CreateNetworkSwitchStackRoutingInterfaceMulticastRouting: TypeAlias = Literal[
    "IGMP snooping querier", "disabled", "enabled"
]
CreateNetworkWirelessAirMarshalRuleType: TypeAlias = Literal["alert", "allow", "block"]
CreateNetworkWirelessRfProfileBandSelectionType: TypeAlias = Literal["ap", "ssid"]
CreateNetworkWirelessRfProfileMinBitrateType: TypeAlias = Literal["band", "ssid"]
CreateOrganizationAdaptivePolicyAclIpVersion: TypeAlias = Literal["any", "ipv4", "ipv6"]
CreateOrganizationAdaptivePolicyPolicyLastEntryRule: TypeAlias = Literal["allow", "default", "deny"]
CreateOrganizationAdminAuthenticationMethod: TypeAlias = Literal["Email"]
CreateOrganizationAdminOrgAccess: TypeAlias = Literal["enterprise", "full", "none", "read-only"]
CreateOrganizationAlertsProfileType: TypeAlias = Literal[
    "appOutage",
    "voipJitter",
    "voipMos",
    "voipPacketLoss",
    "wanLatency",
    "wanPacketLoss",
    "wanStatus",
    "wanUtilization",
]
CreateOrganizationDevicesControllerMigrationTarget: TypeAlias = Literal["wirelessController"]
CreateOrganizationNetworkProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
CreateOrganizationSmAdminsRoleScope: TypeAlias = Literal[
    "all_tags", "some", "without_all_tags", "without_some"
]
GetAdministeredLicensingSubscriptionSubscriptionsProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetAdministeredLicensingSubscriptionSubscriptionsStatuses: TypeAlias = list[
    Literal["active", "canceled", "expired", "inactive", "out_of_compliance"]
]
GetDeviceCameraAnalyticsOverviewObjectType: TypeAlias = Literal["person", "vehicle"]
GetDeviceCameraAnalyticsRecentObjectType: TypeAlias = Literal["person", "vehicle"]
GetDeviceCameraAnalyticsZoneHistoryObjectType: TypeAlias = Literal["person", "vehicle"]
GetDeviceLossAndLatencyHistoryUplink: TypeAlias = Literal["cellular", "wan1", "wan2", "wan3"]
GetDeviceSensorCommandsSortOrder: TypeAlias = Literal["ascending", "descending"]
GetDeviceSwitchRoutingInterfacesMode: TypeAlias = Literal[
    "loopback", "oob_management", "routed", "vlan"
]
GetDeviceSwitchRoutingInterfacesProtocol: TypeAlias = Literal["ipv4", "ipv6"]
GetDeviceWirelessConnectionStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetDeviceWirelessConnectionStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetDeviceWirelessLatencyStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetDeviceWirelessLatencyStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkApplianceClientSecurityEventsSortOrder: TypeAlias = Literal["ascending", "descending"]
GetNetworkApplianceSecurityEventsSortOrder: TypeAlias = Literal["ascending", "descending"]
GetNetworkClientsApplicationUsageSsidNumber: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkClientsRecentDeviceConnections: TypeAlias = list[Literal["Wired", "Wireless"]]
GetNetworkClientsStatuses: TypeAlias = list[Literal["Offline", "Online"]]
GetNetworkClientsUsageHistoriesSsidNumber: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkEventsProductType: TypeAlias = Literal[
    "appliance",
    "camera",
    "campusGateway",
    "cellularGateway",
    "secureConnect",
    "switch",
    "systemsManager",
    "wireless",
    "wirelessController",
]
GetNetworkSplashLoginAttemptsSsidNumber: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkSwitchStackRoutingInterfacesMode: TypeAlias = Literal[
    "loopback", "oob_management", "routed", "vlan"
]
GetNetworkSwitchStackRoutingInterfacesProtocol: TypeAlias = Literal["ipv4", "ipv6"]
GetNetworkTrafficDeviceType: TypeAlias = Literal["appliance", "combined", "switch", "wireless"]
GetNetworkVlanProfilesAssignmentsByDeviceProductTypes: TypeAlias = list[
    Literal["switch", "wireless"]
]
GetNetworkWirelessChannelUtilizationHistoryBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientConnectionStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientConnectionStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessClientConnectivityEventsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientConnectivityEventsIncludedSeverities: TypeAlias = list[
    Literal["bad", "good", "info", "warn"]
]
GetNetworkWirelessClientConnectivityEventsSortOrder: TypeAlias = Literal["ascending", "descending"]
GetNetworkWirelessClientConnectivityEventsSsidNumber: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessClientConnectivityEventsTypes: TypeAlias = list[
    Literal["assoc", "auth", "connection", "deauth", "dhcp", "disassoc", "dns", "roam", "sticky"]
]
GetNetworkWirelessClientCountHistoryBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientLatencyStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientLatencyStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessClientsConnectionStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientsConnectionStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessClientsLatencyStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessClientsLatencyStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessConnectionStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessConnectionStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessDataRateHistoryBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessDevicesConnectionStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessDevicesConnectionStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessDevicesLatencyStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessDevicesLatencyStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessFailedConnectionsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessFailedConnectionsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessLatencyHistoryAccessCategory: TypeAlias = Literal[
    "backgroundTraffic", "bestEffortTraffic", "videoTraffic", "voiceTraffic"
]
GetNetworkWirelessLatencyHistoryBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessLatencyStatsBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessLatencyStatsSsid: TypeAlias = Literal[
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14
]
GetNetworkWirelessSignalQualityHistoryBand: TypeAlias = Literal["2.4", "5", "6"]
GetNetworkWirelessUsageHistoryBand: TypeAlias = Literal["2.4", "5", "6"]
GetOrganizationActionBatchesStatus: TypeAlias = Literal["completed", "failed", "pending"]
GetOrganizationApiRequestsMethod: TypeAlias = Literal["DELETE", "GET", "POST", "PUT"]
GetOrganizationApiRequestsOverviewResponseCodesByIntervalVersion: TypeAlias = Literal[0, 1]
GetOrganizationApiRequestsVersion: TypeAlias = Literal[0, 1]
GetOrganizationApplianceSecurityEventsSortOrder: TypeAlias = Literal["ascending", "descending"]
GetOrganizationAssuranceAlertsCategory: TypeAlias = Literal[
    "configuration", "connectivity", "device_health", "insights"
]
GetOrganizationAssuranceAlertsDeviceTypes: TypeAlias = list[
    Literal[
        "Campus Gateway",
        "Catalyst AP",
        "Catalyst Controller",
        "Catalyst Switch",
        "MCG",
        "MG",
        "MR",
        "MS",
        "MT",
        "MV",
        "MX",
        "VMX",
        "WLC",
        "Z",
    ]
]
GetOrganizationAssuranceAlertsOverviewByNetworkCategory: TypeAlias = Literal[
    "configuration", "connectivity", "device_health", "insights"
]
GetOrganizationAssuranceAlertsOverviewByNetworkDeviceTypes: TypeAlias = list[
    Literal[
        "Campus Gateway",
        "Catalyst AP",
        "Catalyst Controller",
        "Catalyst Switch",
        "MCG",
        "MG",
        "MR",
        "MS",
        "MT",
        "MV",
        "MX",
        "VMX",
        "WLC",
        "Z",
    ]
]
GetOrganizationAssuranceAlertsOverviewByNetworkSortOrder: TypeAlias = Literal[
    "ascending", "descending"
]
GetOrganizationAssuranceAlertsOverviewByNetworkTypes: TypeAlias = list[
    Literal[
        "aaa_not_enabled",
        "acl_ipv4_conflict",
        "afc_height_empty",
        "afc_status_bad",
        "ap_became_repeater",
        "ap_noauth",
        "ap_tunnel_down",
        "arp_failure",
        "asymmetry",
        "aurora1_subnet_overlap",
        "auto_vpn_failure",
        "bad_connectivity",
        "bad_gateway",
        "bad_ip6conf",
        "bad_ipconf",
        "bad_vlanconf",
        "ccd",
        "cellular_data_cap",
        "cellular_failover",
        "cellular_failover_bandwidth",
        "cellular_up_down",
        "certificate_enrollment",
        "certificate_expiration",
        "certificate_renewal",
        "client_wayfinding_clustering_warning",
        "client_wayfinding_missing_config",
        "cloud_archive_alert",
        "collisions_errors",
        "config_bad_fetch",
        "config_error",
        "config_stale",
        "configuration_change",
        "console_error_authorization",
        "console_error_timeout",
        "country_mismatch",
        "crc_errors",
        "dashboard_config_generation_failure",
        "detected_country_mismatch",
        "device_access_issue",
        "device_config_failure",
        "device_no_space",
        "device_ping_status",
        "dfs_event_pattern",
        "disassociation",
        "dns_down",
        "dom_stats_alert",
        "door_tamper",
        "eapol_test_failed",
        "ethernet_negotiation_failure",
        "eu_regulatory_firmware_mismatch",
        "fan_down",
        "firewall",
        "firmware_version",
        "frags_errors",
        "high_cpu_mx",
        "high_interference",
        "high_memory_mx",
        "high_temperature_mx",
        "http_acl_ipv6_conflict",
        "https_session_modules_conflict",
        "insecure_sm_networks_disabled_enrollment_auth_alert",
        "insight_web_app",
        "invalid_config",
        "iot_orchestrator_grpc_down",
        "ip_conflict",
        "isp_issue_local_branch",
        "jabbers_errors",
        "known_hardware_problem",
        "l3_dynamic_routes_overflow",
        "l3_hosts_overflow",
        "line_vty_conflict",
        "line_vty_error",
        "low_power",
        "mac_flap_alert",
        "manual_config_fix_required",
        "manual_country_mismatch",
        "mars_read_only_ap_unreachable",
        "meraki_shelluser_conflict",
        "meraki_tdluser_conflict",
        "meraki_user_conflict",
        "mg_safe_mode",
        "mgmt_uplink_vlan_mismatch",
        "missing_config_options",
        "missized_errors",
        "mmc_issue",
        "monitoring_stack_error",
        "monitoring_tls_tunnel_connected",
        "monitoring_unsupported_version",
        "mps_down",
        "netconf_abnormal",
        "netconf_acl_ipv6_conflict",
        "netconf_error_authentication",
        "netconf_error_timeout",
        "no_dna_license",
        "no_enough_vty_num",
        "no_telemetry",
        "node_check",
        "not_supported_compression_algorithm",
        "not_supported_hostkey_algorithm",
        "not_supported_kex_algorithm",
        "not_supported_mac_algorithm",
        "not_supported_publickey_algorithm",
        "not_supported_ssh_algorithm",
        "ntp_issue",
        "odd_upstream_gateway",
        "openroaming_firmware_incompatible",
        "pcc_apns_check_cert",
        "pcc_apns_expired",
        "pcc_apns_expires_soon",
        "pcc_duplicate_device_identifier",
        "pcc_duplicate_imei",
        "pcc_empty_device_identifier",
        "pcc_empty_imei",
        "pcc_self_signed_scep_expired",
        "pcc_self_signed_scep_expires_soon",
        "pending_config_approval",
        "poe_denied",
        "poe_overload",
        "poe_power_error",
        "port_channel_mixed_speed_ports",
        "primary_uplink_status",
        "probe_cable_unknown",
        "push_api_device_availability",
        "radar_detection",
        "reboot_count",
        "reboot_count_no_xmit_mon",
        "reboot_count_panic",
        "reg_dom_mismatch",
        "rogue_dhcp",
        "rps_backup",
        "rps_down",
        "secure_connect_auth_failure",
        "secure_connect_auth_in_progress",
        "secure_connect_auth_timeout",
        "speed_downshift",
        "ssh_error_authentication",
        "ssh_error_authorization",
        "ssh_error_timeout",
        "ssh_port_rotary_conflict",
        "ssid_radius_server",
        "stack_misconfigured",
        "stack_not_configured",
        "start_monitoring_provisioning",
        "sticky_client",
        "stp_bpdu_conflict",
        "stp_bpdu_delay",
        "stp_bpduguard_active",
        "stp_loopguard_active",
        "stp_root_status_changed",
        "stp_rootguard_active",
        "stp_tcn_errors",
        "switch_not_setup_as_stack",
        "switch_required_vlans_missing",
        "switch_reserved_vlans",
        "switchport_allowed_vlans_missing",
        "temperature_cable_disconnect",
        "thousand_eyes_application_alert",
        "traffic_shaping_rule_saturation",
        "udld_err_n_mismatch",
        "udld_err_tx_rx_loop",
        "udld_err_unidir",
        "unknown_config_options",
        "unreachable",
        "unseen",
        "uplink_saturation",
        "using_mtun_http",
        "vlan_disconnect",
        "vlan_mismatch",
        "vlan_prefix_starvation",
        "vmx_incompatible_firmware",
        "voip_jitter",
        "voip_mos",
        "voip_packet_loss",
        "vpn_backhaul",
        "vpn_outage",
        "vrrp_failover",
        "vwlc_unclaimed_standby",
        "wan_latency",
        "wan_packet_loss",
        "wan_status",
        "wan_usage",
        "water_cable_disconnect",
        "water_usb_connect",
        "wlc_add_standby",
        "wlc_ap_guardrail",
        "wlc_ap_limit",
        "wlc_ap_onboard",
        "wlc_ha_active_recovery",
        "wlc_ha_fail_over_past_day",
        "wlc_ha_standby_offline",
        "wlc_ha_standby_recovery",
        "wlc_interface_errors",
        "wlc_unassigned_ap",
        "wpa3_warning",
        "wrong_console_credentials",
        "yang_authz_conflict",
        "yang_process_abnormal",
        "z_canary_alert",
        "z_canary_priority_alert",
    ]
]
GetOrganizationAssuranceAlertsOverviewByTypeCategory: TypeAlias = Literal[
    "configuration", "connectivity", "device_health", "insights"
]
GetOrganizationAssuranceAlertsOverviewByTypeDeviceTypes: TypeAlias = list[
    Literal[
        "Campus Gateway",
        "Catalyst AP",
        "Catalyst Controller",
        "Catalyst Switch",
        "MCG",
        "MG",
        "MR",
        "MS",
        "MT",
        "MV",
        "MX",
        "VMX",
        "WLC",
        "Z",
    ]
]
GetOrganizationAssuranceAlertsOverviewByTypeSortBy: TypeAlias = Literal[
    "count", "lastAlertedAt", "networkCount", "severity", "startedAt"
]
GetOrganizationAssuranceAlertsOverviewByTypeSortOrder: TypeAlias = Literal[
    "ascending", "descending"
]
GetOrganizationAssuranceAlertsOverviewByTypeTypes: TypeAlias = list[
    Literal[
        "aaa_not_enabled",
        "acl_ipv4_conflict",
        "afc_height_empty",
        "afc_status_bad",
        "ap_became_repeater",
        "ap_noauth",
        "ap_tunnel_down",
        "arp_failure",
        "asymmetry",
        "aurora1_subnet_overlap",
        "auto_vpn_failure",
        "bad_connectivity",
        "bad_gateway",
        "bad_ip6conf",
        "bad_ipconf",
        "bad_vlanconf",
        "ccd",
        "cellular_data_cap",
        "cellular_failover",
        "cellular_failover_bandwidth",
        "cellular_up_down",
        "certificate_enrollment",
        "certificate_expiration",
        "certificate_renewal",
        "client_wayfinding_clustering_warning",
        "client_wayfinding_missing_config",
        "cloud_archive_alert",
        "collisions_errors",
        "config_bad_fetch",
        "config_error",
        "config_stale",
        "configuration_change",
        "console_error_authorization",
        "console_error_timeout",
        "country_mismatch",
        "crc_errors",
        "dashboard_config_generation_failure",
        "detected_country_mismatch",
        "device_access_issue",
        "device_config_failure",
        "device_no_space",
        "device_ping_status",
        "dfs_event_pattern",
        "disassociation",
        "dns_down",
        "dom_stats_alert",
        "door_tamper",
        "eapol_test_failed",
        "ethernet_negotiation_failure",
        "eu_regulatory_firmware_mismatch",
        "fan_down",
        "firewall",
        "firmware_version",
        "frags_errors",
        "high_cpu_mx",
        "high_interference",
        "high_memory_mx",
        "high_temperature_mx",
        "http_acl_ipv6_conflict",
        "https_session_modules_conflict",
        "insecure_sm_networks_disabled_enrollment_auth_alert",
        "insight_web_app",
        "invalid_config",
        "iot_orchestrator_grpc_down",
        "ip_conflict",
        "isp_issue_local_branch",
        "jabbers_errors",
        "known_hardware_problem",
        "l3_dynamic_routes_overflow",
        "l3_hosts_overflow",
        "line_vty_conflict",
        "line_vty_error",
        "low_power",
        "mac_flap_alert",
        "manual_config_fix_required",
        "manual_country_mismatch",
        "mars_read_only_ap_unreachable",
        "meraki_shelluser_conflict",
        "meraki_tdluser_conflict",
        "meraki_user_conflict",
        "mg_safe_mode",
        "mgmt_uplink_vlan_mismatch",
        "missing_config_options",
        "missized_errors",
        "mmc_issue",
        "monitoring_stack_error",
        "monitoring_tls_tunnel_connected",
        "monitoring_unsupported_version",
        "mps_down",
        "netconf_abnormal",
        "netconf_acl_ipv6_conflict",
        "netconf_error_authentication",
        "netconf_error_timeout",
        "no_dna_license",
        "no_enough_vty_num",
        "no_telemetry",
        "node_check",
        "not_supported_compression_algorithm",
        "not_supported_hostkey_algorithm",
        "not_supported_kex_algorithm",
        "not_supported_mac_algorithm",
        "not_supported_publickey_algorithm",
        "not_supported_ssh_algorithm",
        "ntp_issue",
        "odd_upstream_gateway",
        "openroaming_firmware_incompatible",
        "pcc_apns_check_cert",
        "pcc_apns_expired",
        "pcc_apns_expires_soon",
        "pcc_duplicate_device_identifier",
        "pcc_duplicate_imei",
        "pcc_empty_device_identifier",
        "pcc_empty_imei",
        "pcc_self_signed_scep_expired",
        "pcc_self_signed_scep_expires_soon",
        "pending_config_approval",
        "poe_denied",
        "poe_overload",
        "poe_power_error",
        "port_channel_mixed_speed_ports",
        "primary_uplink_status",
        "probe_cable_unknown",
        "push_api_device_availability",
        "radar_detection",
        "reboot_count",
        "reboot_count_no_xmit_mon",
        "reboot_count_panic",
        "reg_dom_mismatch",
        "rogue_dhcp",
        "rps_backup",
        "rps_down",
        "secure_connect_auth_failure",
        "secure_connect_auth_in_progress",
        "secure_connect_auth_timeout",
        "speed_downshift",
        "ssh_error_authentication",
        "ssh_error_authorization",
        "ssh_error_timeout",
        "ssh_port_rotary_conflict",
        "ssid_radius_server",
        "stack_misconfigured",
        "stack_not_configured",
        "start_monitoring_provisioning",
        "sticky_client",
        "stp_bpdu_conflict",
        "stp_bpdu_delay",
        "stp_bpduguard_active",
        "stp_loopguard_active",
        "stp_root_status_changed",
        "stp_rootguard_active",
        "stp_tcn_errors",
        "switch_not_setup_as_stack",
        "switch_required_vlans_missing",
        "switch_reserved_vlans",
        "switchport_allowed_vlans_missing",
        "temperature_cable_disconnect",
        "thousand_eyes_application_alert",
        "traffic_shaping_rule_saturation",
        "udld_err_n_mismatch",
        "udld_err_tx_rx_loop",
        "udld_err_unidir",
        "unknown_config_options",
        "unreachable",
        "unseen",
        "uplink_saturation",
        "using_mtun_http",
        "vlan_disconnect",
        "vlan_mismatch",
        "vlan_prefix_starvation",
        "vmx_incompatible_firmware",
        "voip_jitter",
        "voip_mos",
        "voip_packet_loss",
        "vpn_backhaul",
        "vpn_outage",
        "vrrp_failover",
        "vwlc_unclaimed_standby",
        "wan_latency",
        "wan_packet_loss",
        "wan_status",
        "wan_usage",
        "water_cable_disconnect",
        "water_usb_connect",
        "wlc_add_standby",
        "wlc_ap_guardrail",
        "wlc_ap_limit",
        "wlc_ap_onboard",
        "wlc_ha_active_recovery",
        "wlc_ha_fail_over_past_day",
        "wlc_ha_standby_offline",
        "wlc_ha_standby_recovery",
        "wlc_interface_errors",
        "wlc_unassigned_ap",
        "wpa3_warning",
        "wrong_console_credentials",
        "yang_authz_conflict",
        "yang_process_abnormal",
        "z_canary_alert",
        "z_canary_priority_alert",
    ]
]
GetOrganizationAssuranceAlertsOverviewCategory: TypeAlias = Literal[
    "configuration", "connectivity", "device_health", "insights"
]
GetOrganizationAssuranceAlertsOverviewDeviceTypes: TypeAlias = list[
    Literal[
        "Campus Gateway",
        "Catalyst AP",
        "Catalyst Controller",
        "Catalyst Switch",
        "MCG",
        "MG",
        "MR",
        "MS",
        "MT",
        "MV",
        "MX",
        "VMX",
        "WLC",
        "Z",
    ]
]
GetOrganizationAssuranceAlertsOverviewHistoricalCategory: TypeAlias = Literal[
    "configuration", "connectivity", "device_health", "insights"
]
GetOrganizationAssuranceAlertsOverviewHistoricalDeviceTypes: TypeAlias = list[
    Literal[
        "Campus Gateway",
        "Catalyst AP",
        "Catalyst Controller",
        "Catalyst Switch",
        "MCG",
        "MG",
        "MR",
        "MS",
        "MT",
        "MV",
        "MX",
        "VMX",
        "WLC",
        "Z",
    ]
]
GetOrganizationAssuranceAlertsOverviewHistoricalTypes: TypeAlias = list[
    Literal[
        "aaa_not_enabled",
        "acl_ipv4_conflict",
        "afc_height_empty",
        "afc_status_bad",
        "ap_became_repeater",
        "ap_noauth",
        "ap_tunnel_down",
        "arp_failure",
        "asymmetry",
        "aurora1_subnet_overlap",
        "auto_vpn_failure",
        "bad_connectivity",
        "bad_gateway",
        "bad_ip6conf",
        "bad_ipconf",
        "bad_vlanconf",
        "ccd",
        "cellular_data_cap",
        "cellular_failover",
        "cellular_failover_bandwidth",
        "cellular_up_down",
        "certificate_enrollment",
        "certificate_expiration",
        "certificate_renewal",
        "client_wayfinding_clustering_warning",
        "client_wayfinding_missing_config",
        "cloud_archive_alert",
        "collisions_errors",
        "config_bad_fetch",
        "config_error",
        "config_stale",
        "configuration_change",
        "console_error_authorization",
        "console_error_timeout",
        "country_mismatch",
        "crc_errors",
        "dashboard_config_generation_failure",
        "detected_country_mismatch",
        "device_access_issue",
        "device_config_failure",
        "device_no_space",
        "device_ping_status",
        "dfs_event_pattern",
        "disassociation",
        "dns_down",
        "dom_stats_alert",
        "door_tamper",
        "eapol_test_failed",
        "ethernet_negotiation_failure",
        "eu_regulatory_firmware_mismatch",
        "fan_down",
        "firewall",
        "firmware_version",
        "frags_errors",
        "high_cpu_mx",
        "high_interference",
        "high_memory_mx",
        "high_temperature_mx",
        "http_acl_ipv6_conflict",
        "https_session_modules_conflict",
        "insecure_sm_networks_disabled_enrollment_auth_alert",
        "insight_web_app",
        "invalid_config",
        "iot_orchestrator_grpc_down",
        "ip_conflict",
        "isp_issue_local_branch",
        "jabbers_errors",
        "known_hardware_problem",
        "l3_dynamic_routes_overflow",
        "l3_hosts_overflow",
        "line_vty_conflict",
        "line_vty_error",
        "low_power",
        "mac_flap_alert",
        "manual_config_fix_required",
        "manual_country_mismatch",
        "mars_read_only_ap_unreachable",
        "meraki_shelluser_conflict",
        "meraki_tdluser_conflict",
        "meraki_user_conflict",
        "mg_safe_mode",
        "mgmt_uplink_vlan_mismatch",
        "missing_config_options",
        "missized_errors",
        "mmc_issue",
        "monitoring_stack_error",
        "monitoring_tls_tunnel_connected",
        "monitoring_unsupported_version",
        "mps_down",
        "netconf_abnormal",
        "netconf_acl_ipv6_conflict",
        "netconf_error_authentication",
        "netconf_error_timeout",
        "no_dna_license",
        "no_enough_vty_num",
        "no_telemetry",
        "node_check",
        "not_supported_compression_algorithm",
        "not_supported_hostkey_algorithm",
        "not_supported_kex_algorithm",
        "not_supported_mac_algorithm",
        "not_supported_publickey_algorithm",
        "not_supported_ssh_algorithm",
        "ntp_issue",
        "odd_upstream_gateway",
        "openroaming_firmware_incompatible",
        "pcc_apns_check_cert",
        "pcc_apns_expired",
        "pcc_apns_expires_soon",
        "pcc_duplicate_device_identifier",
        "pcc_duplicate_imei",
        "pcc_empty_device_identifier",
        "pcc_empty_imei",
        "pcc_self_signed_scep_expired",
        "pcc_self_signed_scep_expires_soon",
        "pending_config_approval",
        "poe_denied",
        "poe_overload",
        "poe_power_error",
        "port_channel_mixed_speed_ports",
        "primary_uplink_status",
        "probe_cable_unknown",
        "push_api_device_availability",
        "radar_detection",
        "reboot_count",
        "reboot_count_no_xmit_mon",
        "reboot_count_panic",
        "reg_dom_mismatch",
        "rogue_dhcp",
        "rps_backup",
        "rps_down",
        "secure_connect_auth_failure",
        "secure_connect_auth_in_progress",
        "secure_connect_auth_timeout",
        "speed_downshift",
        "ssh_error_authentication",
        "ssh_error_authorization",
        "ssh_error_timeout",
        "ssh_port_rotary_conflict",
        "ssid_radius_server",
        "stack_misconfigured",
        "stack_not_configured",
        "start_monitoring_provisioning",
        "sticky_client",
        "stp_bpdu_conflict",
        "stp_bpdu_delay",
        "stp_bpduguard_active",
        "stp_loopguard_active",
        "stp_root_status_changed",
        "stp_rootguard_active",
        "stp_tcn_errors",
        "switch_not_setup_as_stack",
        "switch_required_vlans_missing",
        "switch_reserved_vlans",
        "switchport_allowed_vlans_missing",
        "temperature_cable_disconnect",
        "thousand_eyes_application_alert",
        "traffic_shaping_rule_saturation",
        "udld_err_n_mismatch",
        "udld_err_tx_rx_loop",
        "udld_err_unidir",
        "unknown_config_options",
        "unreachable",
        "unseen",
        "uplink_saturation",
        "using_mtun_http",
        "vlan_disconnect",
        "vlan_mismatch",
        "vlan_prefix_starvation",
        "vmx_incompatible_firmware",
        "voip_jitter",
        "voip_mos",
        "voip_packet_loss",
        "vpn_backhaul",
        "vpn_outage",
        "vrrp_failover",
        "vwlc_unclaimed_standby",
        "wan_latency",
        "wan_packet_loss",
        "wan_status",
        "wan_usage",
        "water_cable_disconnect",
        "water_usb_connect",
        "wlc_add_standby",
        "wlc_ap_guardrail",
        "wlc_ap_limit",
        "wlc_ap_onboard",
        "wlc_ha_active_recovery",
        "wlc_ha_fail_over_past_day",
        "wlc_ha_standby_offline",
        "wlc_ha_standby_recovery",
        "wlc_interface_errors",
        "wlc_unassigned_ap",
        "wpa3_warning",
        "wrong_console_credentials",
        "yang_authz_conflict",
        "yang_process_abnormal",
        "z_canary_alert",
        "z_canary_priority_alert",
    ]
]
GetOrganizationAssuranceAlertsOverviewTypes: TypeAlias = list[
    Literal[
        "aaa_not_enabled",
        "acl_ipv4_conflict",
        "afc_height_empty",
        "afc_status_bad",
        "ap_became_repeater",
        "ap_noauth",
        "ap_tunnel_down",
        "arp_failure",
        "asymmetry",
        "aurora1_subnet_overlap",
        "auto_vpn_failure",
        "bad_connectivity",
        "bad_gateway",
        "bad_ip6conf",
        "bad_ipconf",
        "bad_vlanconf",
        "ccd",
        "cellular_data_cap",
        "cellular_failover",
        "cellular_failover_bandwidth",
        "cellular_up_down",
        "certificate_enrollment",
        "certificate_expiration",
        "certificate_renewal",
        "client_wayfinding_clustering_warning",
        "client_wayfinding_missing_config",
        "cloud_archive_alert",
        "collisions_errors",
        "config_bad_fetch",
        "config_error",
        "config_stale",
        "configuration_change",
        "console_error_authorization",
        "console_error_timeout",
        "country_mismatch",
        "crc_errors",
        "dashboard_config_generation_failure",
        "detected_country_mismatch",
        "device_access_issue",
        "device_config_failure",
        "device_no_space",
        "device_ping_status",
        "dfs_event_pattern",
        "disassociation",
        "dns_down",
        "dom_stats_alert",
        "door_tamper",
        "eapol_test_failed",
        "ethernet_negotiation_failure",
        "eu_regulatory_firmware_mismatch",
        "fan_down",
        "firewall",
        "firmware_version",
        "frags_errors",
        "high_cpu_mx",
        "high_interference",
        "high_memory_mx",
        "high_temperature_mx",
        "http_acl_ipv6_conflict",
        "https_session_modules_conflict",
        "insecure_sm_networks_disabled_enrollment_auth_alert",
        "insight_web_app",
        "invalid_config",
        "iot_orchestrator_grpc_down",
        "ip_conflict",
        "isp_issue_local_branch",
        "jabbers_errors",
        "known_hardware_problem",
        "l3_dynamic_routes_overflow",
        "l3_hosts_overflow",
        "line_vty_conflict",
        "line_vty_error",
        "low_power",
        "mac_flap_alert",
        "manual_config_fix_required",
        "manual_country_mismatch",
        "mars_read_only_ap_unreachable",
        "meraki_shelluser_conflict",
        "meraki_tdluser_conflict",
        "meraki_user_conflict",
        "mg_safe_mode",
        "mgmt_uplink_vlan_mismatch",
        "missing_config_options",
        "missized_errors",
        "mmc_issue",
        "monitoring_stack_error",
        "monitoring_tls_tunnel_connected",
        "monitoring_unsupported_version",
        "mps_down",
        "netconf_abnormal",
        "netconf_acl_ipv6_conflict",
        "netconf_error_authentication",
        "netconf_error_timeout",
        "no_dna_license",
        "no_enough_vty_num",
        "no_telemetry",
        "node_check",
        "not_supported_compression_algorithm",
        "not_supported_hostkey_algorithm",
        "not_supported_kex_algorithm",
        "not_supported_mac_algorithm",
        "not_supported_publickey_algorithm",
        "not_supported_ssh_algorithm",
        "ntp_issue",
        "odd_upstream_gateway",
        "openroaming_firmware_incompatible",
        "pcc_apns_check_cert",
        "pcc_apns_expired",
        "pcc_apns_expires_soon",
        "pcc_duplicate_device_identifier",
        "pcc_duplicate_imei",
        "pcc_empty_device_identifier",
        "pcc_empty_imei",
        "pcc_self_signed_scep_expired",
        "pcc_self_signed_scep_expires_soon",
        "pending_config_approval",
        "poe_denied",
        "poe_overload",
        "poe_power_error",
        "port_channel_mixed_speed_ports",
        "primary_uplink_status",
        "probe_cable_unknown",
        "push_api_device_availability",
        "radar_detection",
        "reboot_count",
        "reboot_count_no_xmit_mon",
        "reboot_count_panic",
        "reg_dom_mismatch",
        "rogue_dhcp",
        "rps_backup",
        "rps_down",
        "secure_connect_auth_failure",
        "secure_connect_auth_in_progress",
        "secure_connect_auth_timeout",
        "speed_downshift",
        "ssh_error_authentication",
        "ssh_error_authorization",
        "ssh_error_timeout",
        "ssh_port_rotary_conflict",
        "ssid_radius_server",
        "stack_misconfigured",
        "stack_not_configured",
        "start_monitoring_provisioning",
        "sticky_client",
        "stp_bpdu_conflict",
        "stp_bpdu_delay",
        "stp_bpduguard_active",
        "stp_loopguard_active",
        "stp_root_status_changed",
        "stp_rootguard_active",
        "stp_tcn_errors",
        "switch_not_setup_as_stack",
        "switch_required_vlans_missing",
        "switch_reserved_vlans",
        "switchport_allowed_vlans_missing",
        "temperature_cable_disconnect",
        "thousand_eyes_application_alert",
        "traffic_shaping_rule_saturation",
        "udld_err_n_mismatch",
        "udld_err_tx_rx_loop",
        "udld_err_unidir",
        "unknown_config_options",
        "unreachable",
        "unseen",
        "uplink_saturation",
        "using_mtun_http",
        "vlan_disconnect",
        "vlan_mismatch",
        "vlan_prefix_starvation",
        "vmx_incompatible_firmware",
        "voip_jitter",
        "voip_mos",
        "voip_packet_loss",
        "vpn_backhaul",
        "vpn_outage",
        "vrrp_failover",
        "vwlc_unclaimed_standby",
        "wan_latency",
        "wan_packet_loss",
        "wan_status",
        "wan_usage",
        "water_cable_disconnect",
        "water_usb_connect",
        "wlc_add_standby",
        "wlc_ap_guardrail",
        "wlc_ap_limit",
        "wlc_ap_onboard",
        "wlc_ha_active_recovery",
        "wlc_ha_fail_over_past_day",
        "wlc_ha_standby_offline",
        "wlc_ha_standby_recovery",
        "wlc_interface_errors",
        "wlc_unassigned_ap",
        "wpa3_warning",
        "wrong_console_credentials",
        "yang_authz_conflict",
        "yang_process_abnormal",
        "z_canary_alert",
        "z_canary_priority_alert",
    ]
]
GetOrganizationAssuranceAlertsSortBy: TypeAlias = Literal[
    "category", "dismissedAt", "resolvedAt", "severity", "startedAt"
]
GetOrganizationAssuranceAlertsSortOrder: TypeAlias = Literal["ascending", "descending"]
GetOrganizationAssuranceAlertsTypes: TypeAlias = list[
    Literal[
        "aaa_not_enabled",
        "acl_ipv4_conflict",
        "afc_height_empty",
        "afc_status_bad",
        "ap_became_repeater",
        "ap_noauth",
        "ap_tunnel_down",
        "arp_failure",
        "asymmetry",
        "aurora1_subnet_overlap",
        "auto_vpn_failure",
        "bad_connectivity",
        "bad_gateway",
        "bad_ip6conf",
        "bad_ipconf",
        "bad_vlanconf",
        "ccd",
        "cellular_data_cap",
        "cellular_failover",
        "cellular_failover_bandwidth",
        "cellular_up_down",
        "certificate_enrollment",
        "certificate_expiration",
        "certificate_renewal",
        "client_wayfinding_clustering_warning",
        "client_wayfinding_missing_config",
        "cloud_archive_alert",
        "collisions_errors",
        "config_bad_fetch",
        "config_error",
        "config_stale",
        "configuration_change",
        "console_error_authorization",
        "console_error_timeout",
        "country_mismatch",
        "crc_errors",
        "dashboard_config_generation_failure",
        "detected_country_mismatch",
        "device_access_issue",
        "device_config_failure",
        "device_no_space",
        "device_ping_status",
        "dfs_event_pattern",
        "disassociation",
        "dns_down",
        "dom_stats_alert",
        "door_tamper",
        "eapol_test_failed",
        "ethernet_negotiation_failure",
        "eu_regulatory_firmware_mismatch",
        "fan_down",
        "firewall",
        "firmware_version",
        "frags_errors",
        "high_cpu_mx",
        "high_interference",
        "high_memory_mx",
        "high_temperature_mx",
        "http_acl_ipv6_conflict",
        "https_session_modules_conflict",
        "insecure_sm_networks_disabled_enrollment_auth_alert",
        "insight_web_app",
        "invalid_config",
        "iot_orchestrator_grpc_down",
        "ip_conflict",
        "isp_issue_local_branch",
        "jabbers_errors",
        "known_hardware_problem",
        "l3_dynamic_routes_overflow",
        "l3_hosts_overflow",
        "line_vty_conflict",
        "line_vty_error",
        "low_power",
        "mac_flap_alert",
        "manual_config_fix_required",
        "manual_country_mismatch",
        "mars_read_only_ap_unreachable",
        "meraki_shelluser_conflict",
        "meraki_tdluser_conflict",
        "meraki_user_conflict",
        "mg_safe_mode",
        "mgmt_uplink_vlan_mismatch",
        "missing_config_options",
        "missized_errors",
        "mmc_issue",
        "monitoring_stack_error",
        "monitoring_tls_tunnel_connected",
        "monitoring_unsupported_version",
        "mps_down",
        "netconf_abnormal",
        "netconf_acl_ipv6_conflict",
        "netconf_error_authentication",
        "netconf_error_timeout",
        "no_dna_license",
        "no_enough_vty_num",
        "no_telemetry",
        "node_check",
        "not_supported_compression_algorithm",
        "not_supported_hostkey_algorithm",
        "not_supported_kex_algorithm",
        "not_supported_mac_algorithm",
        "not_supported_publickey_algorithm",
        "not_supported_ssh_algorithm",
        "ntp_issue",
        "odd_upstream_gateway",
        "openroaming_firmware_incompatible",
        "pcc_apns_check_cert",
        "pcc_apns_expired",
        "pcc_apns_expires_soon",
        "pcc_duplicate_device_identifier",
        "pcc_duplicate_imei",
        "pcc_empty_device_identifier",
        "pcc_empty_imei",
        "pcc_self_signed_scep_expired",
        "pcc_self_signed_scep_expires_soon",
        "pending_config_approval",
        "poe_denied",
        "poe_overload",
        "poe_power_error",
        "port_channel_mixed_speed_ports",
        "primary_uplink_status",
        "probe_cable_unknown",
        "push_api_device_availability",
        "radar_detection",
        "reboot_count",
        "reboot_count_no_xmit_mon",
        "reboot_count_panic",
        "reg_dom_mismatch",
        "rogue_dhcp",
        "rps_backup",
        "rps_down",
        "secure_connect_auth_failure",
        "secure_connect_auth_in_progress",
        "secure_connect_auth_timeout",
        "speed_downshift",
        "ssh_error_authentication",
        "ssh_error_authorization",
        "ssh_error_timeout",
        "ssh_port_rotary_conflict",
        "ssid_radius_server",
        "stack_misconfigured",
        "stack_not_configured",
        "start_monitoring_provisioning",
        "sticky_client",
        "stp_bpdu_conflict",
        "stp_bpdu_delay",
        "stp_bpduguard_active",
        "stp_loopguard_active",
        "stp_root_status_changed",
        "stp_rootguard_active",
        "stp_tcn_errors",
        "switch_not_setup_as_stack",
        "switch_required_vlans_missing",
        "switch_reserved_vlans",
        "switchport_allowed_vlans_missing",
        "temperature_cable_disconnect",
        "thousand_eyes_application_alert",
        "traffic_shaping_rule_saturation",
        "udld_err_n_mismatch",
        "udld_err_tx_rx_loop",
        "udld_err_unidir",
        "unknown_config_options",
        "unreachable",
        "unseen",
        "uplink_saturation",
        "using_mtun_http",
        "vlan_disconnect",
        "vlan_mismatch",
        "vlan_prefix_starvation",
        "vmx_incompatible_firmware",
        "voip_jitter",
        "voip_mos",
        "voip_packet_loss",
        "vpn_backhaul",
        "vpn_outage",
        "vrrp_failover",
        "vwlc_unclaimed_standby",
        "wan_latency",
        "wan_packet_loss",
        "wan_status",
        "wan_usage",
        "water_cable_disconnect",
        "water_usb_connect",
        "wlc_add_standby",
        "wlc_ap_guardrail",
        "wlc_ap_limit",
        "wlc_ap_onboard",
        "wlc_ha_active_recovery",
        "wlc_ha_fail_over_past_day",
        "wlc_ha_standby_offline",
        "wlc_ha_standby_recovery",
        "wlc_interface_errors",
        "wlc_unassigned_ap",
        "wpa3_warning",
        "wrong_console_credentials",
        "yang_authz_conflict",
        "yang_process_abnormal",
        "z_canary_alert",
        "z_canary_priority_alert",
    ]
]
GetOrganizationCameraDetectionsHistoryByBoundaryByIntervalBoundaryTypes: TypeAlias = list[
    Literal["person", "vehicle"]
]
GetOrganizationDevicesAvailabilitiesChangeHistoryStatuses: TypeAlias = list[
    Literal["alerting", "dormant", "offline", "online"]
]
GetOrganizationDevicesAvailabilitiesStatuses: TypeAlias = list[
    Literal["alerting", "dormant", "offline", "online"]
]
GetOrganizationDevicesAvailabilitiesTagsFilterType: TypeAlias = Literal[
    "withAllTags", "withAnyTags"
]
GetOrganizationDevicesControllerMigrationsTarget: TypeAlias = Literal["wirelessController"]
GetOrganizationDevicesOverviewByModelProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationDevicesPacketCaptureCapturesSortOrder: TypeAlias = Literal["ascending", "descending"]
GetOrganizationDevicesPowerModulesStatusesByDeviceTagsFilterType: TypeAlias = Literal[
    "withAllTags", "withAnyTags"
]
GetOrganizationDevicesProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationDevicesProvisioningStatusesStatus: TypeAlias = Literal[
    "complete", "incomplete", "unprovisioned"
]
GetOrganizationDevicesProvisioningStatusesTagsFilterType: TypeAlias = Literal[
    "withAllTags", "withAnyTags"
]
GetOrganizationDevicesSensorMetrics: TypeAlias = list[
    Literal[
        "apparentPower",
        "battery",
        "button",
        "co2",
        "current",
        "door",
        "downstreamPower",
        "energy",
        "frequency",
        "humidity",
        "indoorAirQuality",
        "noise",
        "pm25",
        "powerFactor",
        "realPower",
        "remoteLockoutSwitch",
        "temperature",
        "tvoc",
        "voltage",
        "water",
    ]
]
GetOrganizationDevicesStatusesOverviewProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationDevicesStatusesProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationDevicesStatusesStatuses: TypeAlias = list[
    Literal["alerting", "dormant", "offline", "online"]
]
GetOrganizationDevicesStatusesTagsFilterType: TypeAlias = Literal["withAllTags", "withAnyTags"]
GetOrganizationDevicesSystemMemoryUsageHistoryByIntervalProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationDevicesTagsFilterType: TypeAlias = Literal["withAllTags", "withAnyTags"]
GetOrganizationDevicesUplinksAddressesByDeviceTagsFilterType: TypeAlias = Literal[
    "withAllTags", "withAnyTags"
]
GetOrganizationDevicesUplinksLossAndLatencyUplink: TypeAlias = Literal[
    "cellular", "wan1", "wan2", "wan3"
]
GetOrganizationFirmwareUpgradesByDeviceUpgradeStatuses: TypeAlias = list[
    Literal["canceled", "completed", "scheduled", "started"]
]
GetOrganizationInventoryDevicesEoxStatuses: TypeAlias = list[
    Literal["endOfSale", "endOfSupport", "nearEndOfSupport", "null"]
]
GetOrganizationInventoryDevicesProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationInventoryDevicesTagsFilterType: TypeAlias = Literal["withAllTags", "withAnyTags"]
GetOrganizationInventoryDevicesUsedState: TypeAlias = Literal["unused", "used"]
GetOrganizationInventoryOnboardingCloudMonitoringNetworksDeviceType: TypeAlias = Literal[
    "switch", "wireless_controller"
]
GetOrganizationLicensesState: TypeAlias = Literal[
    "active", "expired", "expiring", "recentlyQueued", "unused", "unusedActive"
]
GetOrganizationNetworksProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationNetworksTagsFilterType: TypeAlias = Literal["withAllTags", "withAnyTags"]
GetOrganizationOpenapiSpecVersion: TypeAlias = Literal[2, 3]
GetOrganizationSensorReadingsHistoryMetrics: TypeAlias = list[
    Literal[
        "apparentPower",
        "battery",
        "button",
        "co2",
        "current",
        "door",
        "downstreamPower",
        "frequency",
        "humidity",
        "indoorAirQuality",
        "noise",
        "pm25",
        "powerFactor",
        "realPower",
        "remoteLockoutSwitch",
        "temperature",
        "tvoc",
        "voltage",
        "water",
    ]
]
GetOrganizationSensorReadingsLatestMetrics: TypeAlias = list[
    Literal[
        "apparentPower",
        "battery",
        "button",
        "co2",
        "current",
        "door",
        "downstreamPower",
        "frequency",
        "humidity",
        "indoorAirQuality",
        "noise",
        "pm25",
        "powerFactor",
        "rawTemperature",
        "realPower",
        "remoteLockoutSwitch",
        "temperature",
        "tvoc",
        "voltage",
        "water",
    ]
]
GetOrganizationWebhooksAlertTypesProductType: TypeAlias = Literal[
    "appliance", "camera", "cellularGateway", "platform", "sensor", "sm", "switch", "wireless"
]
GetOrganizationWirelessRadioRrmByNetworkSortOrder: TypeAlias = Literal["ascending", "descending"]
GetOrganizationWirelessRfProfilesAssignmentsByDeviceProductTypes: TypeAlias = list[
    Literal[
        "appliance",
        "camera",
        "campusGateway",
        "cellularGateway",
        "secureConnect",
        "sensor",
        "switch",
        "systemsManager",
        "wireless",
        "wirelessController",
    ]
]
GetOrganizationWirelessSsidsFirewallIsolationAllowlistEntriesSsids: TypeAlias = list[
    Literal[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14]
]
ProvisionNetworkClientsDevicePolicy: TypeAlias = Literal[
    "Allowed", "Blocked", "Group policy", "Normal", "Per connection"
]
UpdateDeviceCameraQualityAndRetentionMotionDetectorVersion: TypeAlias = Literal[1, 2]
UpdateDeviceCameraQualityAndRetentionQuality: TypeAlias = Literal[
    "Enhanced", "High", "Standard", "Ultra"
]
UpdateDeviceCameraQualityAndRetentionResolution: TypeAlias = Literal[
    "1080x1080", "1280x720", "1920x1080", "2112x2112", "2688x1512", "2880x2880", "3840x2160"
]
UpdateDeviceSwitchPortAccessPolicyType: TypeAlias = Literal[
    "Custom access policy", "MAC allow list", "Open", "Sticky MAC allow list"
]
UpdateDeviceSwitchPortStpGuard: TypeAlias = Literal[
    "bpdu guard", "disabled", "loop guard", "root guard"
]
UpdateDeviceSwitchPortType: TypeAlias = Literal["access", "dad", "routed", "stack", "svl", "trunk"]
UpdateDeviceSwitchPortUdld: TypeAlias = Literal["Alert only", "Enforce"]
UpdateDeviceSwitchRoutingInterfaceDhcpDhcpLeaseTime: TypeAlias = Literal[
    "1 day", "1 hour", "1 week", "12 hours", "30 minutes", "4 hours"
]
UpdateDeviceSwitchRoutingInterfaceDhcpDhcpMode: TypeAlias = Literal[
    "dhcpDisabled", "dhcpRelay", "dhcpServer"
]
UpdateDeviceSwitchRoutingInterfaceDhcpDnsNameserversOption: TypeAlias = Literal[
    "custom", "googlePublicDns", "openDns"
]
UpdateDeviceSwitchRoutingInterfaceMulticastRouting: TypeAlias = Literal[
    "IGMP snooping querier", "disabled", "enabled"
]
UpdateNetworkApplianceContentFilteringUrlCategoryListSize: TypeAlias = Literal[
    "fullList", "topSites"
]
UpdateNetworkApplianceFirewallFirewalledServiceAccess: TypeAlias = Literal[
    "blocked", "restricted", "unrestricted"
]
UpdateNetworkApplianceSecurityIntrusionIdsRulesets: TypeAlias = Literal[
    "balanced", "connectivity", "security"
]
UpdateNetworkApplianceSecurityIntrusionMode: TypeAlias = Literal[
    "detection", "disabled", "prevention"
]
UpdateNetworkApplianceSecurityMalwareMode: TypeAlias = Literal["disabled", "enabled"]
UpdateNetworkApplianceSettingsClientTrackingMethod: TypeAlias = Literal[
    "IP address", "MAC address", "Unique client identifier"
]
UpdateNetworkApplianceSettingsDeploymentMode: TypeAlias = Literal["passthrough", "routed"]
UpdateNetworkApplianceSsidAuthMode: TypeAlias = Literal[
    "8021x-meraki", "8021x-radius", "open", "psk"
]
UpdateNetworkApplianceSsidEncryptionMode: TypeAlias = Literal["wep", "wpa"]
UpdateNetworkApplianceSsidWpaEncryptionMode: TypeAlias = Literal[
    "WPA1 and WPA2", "WPA2 only", "WPA3 Transition Mode", "WPA3 only"
]
UpdateNetworkApplianceVlanDhcpHandling: TypeAlias = Literal[
    "Do not respond to DHCP requests", "Relay DHCP to another server", "Run a DHCP server"
]
UpdateNetworkApplianceVlanDhcpLeaseTime: TypeAlias = Literal[
    "1 day", "1 hour", "1 week", "12 hours", "30 minutes", "4 hours"
]
UpdateNetworkApplianceVlanTemplateVlanType: TypeAlias = Literal["same", "unique"]
UpdateNetworkApplianceVpnSiteToSiteVpnMode: TypeAlias = Literal["hub", "none", "spoke"]
UpdateNetworkGroupPolicySplashAuthSettings: TypeAlias = Literal["bypass", "network default"]
UpdateNetworkSnmpAccess: TypeAlias = Literal["community", "none", "users"]
UpdateNetworkSwitchAccessPolicyAccessPolicyType: TypeAlias = Literal[
    "802.1x", "Hybrid authentication", "MAC authentication bypass"
]
UpdateNetworkSwitchAccessPolicyHostMode: TypeAlias = Literal[
    "Multi-Auth", "Multi-Domain", "Multi-Host", "Single-Host"
]
UpdateNetworkSwitchAlternateManagementInterfaceProtocols: TypeAlias = list[
    Literal["radius", "snmp", "syslog"]
]
UpdateNetworkSwitchDhcpServerPolicyDefaultPolicy: TypeAlias = Literal["allow", "block"]
UpdateNetworkSwitchQosRuleProtocol: TypeAlias = Literal["ANY", "TCP", "UDP"]
UpdateNetworkSwitchStackRoutingInterfaceDhcpDhcpLeaseTime: TypeAlias = Literal[
    "1 day", "1 hour", "1 week", "12 hours", "30 minutes", "4 hours"
]
UpdateNetworkSwitchStackRoutingInterfaceDhcpDhcpMode: TypeAlias = Literal[
    "dhcpDisabled", "dhcpRelay", "dhcpServer"
]
UpdateNetworkSwitchStackRoutingInterfaceDhcpDnsNameserversOption: TypeAlias = Literal[
    "custom", "googlePublicDns", "openDns"
]
UpdateNetworkSwitchStackRoutingInterfaceMulticastRouting: TypeAlias = Literal[
    "IGMP snooping querier", "disabled", "enabled"
]
UpdateNetworkTrafficAnalysisMode: TypeAlias = Literal["basic", "detailed", "disabled"]
UpdateNetworkWirelessAirMarshalRuleType: TypeAlias = Literal["alert", "allow", "block"]
UpdateNetworkWirelessAirMarshalSettingsDefaultPolicy: TypeAlias = Literal["allow", "block"]
UpdateNetworkWirelessAlternateManagementInterfaceProtocols: TypeAlias = list[
    Literal["ldap", "radius", "snmp", "syslog"]
]
UpdateNetworkWirelessBluetoothSettingsMajorMinorAssignmentMode: TypeAlias = Literal[
    "Non-unique", "Unique"
]
UpdateNetworkWirelessElectronicShelfLabelMode: TypeAlias = Literal["Bluetooth", "high frequency"]
UpdateNetworkWirelessRfProfileBandSelectionType: TypeAlias = Literal["ap", "ssid"]
UpdateNetworkWirelessRfProfileMinBitrateType: TypeAlias = Literal["band", "ssid"]
UpdateNetworkWirelessSettingsUpgradeStrategy: TypeAlias = Literal[
    "minimizeClientDowntime", "minimizeUpgradeTime"
]
UpdateNetworkWirelessSsidAuthMode: TypeAlias = Literal[
    "8021x-entra",
    "8021x-google",
    "8021x-localradius",
    "8021x-meraki",
    "8021x-nac",
    "8021x-radius",
    "ipsk-with-nac",
    "ipsk-with-radius",
    "ipsk-with-radius-easy-psk",
    "ipsk-without-radius",
    "open",
    "open-enhanced",
    "open-with-nac",
    "open-with-radius",
    "psk",
]
UpdateNetworkWirelessSsidEncryptionMode: TypeAlias = Literal["open", "wep", "wpa", "wpa-eap"]
UpdateNetworkWirelessSsidEnterpriseAdminAccess: TypeAlias = Literal[
    "access disabled", "access enabled"
]
UpdateNetworkWirelessSsidHotspot20NetworkAccessType: TypeAlias = Literal[
    "Chargeable public network",
    "Emergency services only network",
    "Free public network",
    "Personal device network",
    "Private network",
    "Private network with guest access",
    "Test or experimental",
    "Wildcard",
]
UpdateNetworkWirelessSsidRadiusAttributeForGroupPolicies: TypeAlias = Literal[
    "Airespace-ACL-Name", "Aruba-User-Role", "Filter-Id", "Reply-Message"
]
UpdateNetworkWirelessSsidRadiusFailoverPolicy: TypeAlias = Literal["Allow access", "Deny access"]
UpdateNetworkWirelessSsidRadiusLoadBalancingPolicy: TypeAlias = Literal[
    "Round robin", "Strict priority order"
]
UpdateNetworkWirelessSsidSplashPage: TypeAlias = Literal[
    "Billing",
    "Cisco ISE",
    "Click-through splash page",
    "Facebook Wi-Fi",
    "Google Apps domain",
    "Google OAuth",
    "Microsoft Entra ID",
    "None",
    "Password-protected with Active Directory",
    "Password-protected with LDAP",
    "Password-protected with Meraki RADIUS",
    "Password-protected with custom RADIUS",
    "SMS authentication",
    "Sponsored guest",
    "Systems Manager Sentry",
]
UpdateNetworkWirelessSsidSplashSettingsControllerDisconnectionBehavior: TypeAlias = Literal[
    "default", "open", "restricted"
]
UpdateNetworkWirelessSsidSplashSettingsSplashTimeout: TypeAlias = Literal[
    30, 60, 120, 240, 480, 720, 1080, 1440, 2880, 5760, 7200, 10080, 20160, 43200, 86400, 129600
]
UpdateNetworkWirelessSsidWpaEncryptionMode: TypeAlias = Literal[
    "WPA1 and WPA2",
    "WPA1 only",
    "WPA2 only",
    "WPA3 192-bit Security",
    "WPA3 Transition Mode",
    "WPA3 only",
]
UpdateOrganizationAdaptivePolicyAclIpVersion: TypeAlias = Literal["any", "ipv4", "ipv6"]
UpdateOrganizationAdaptivePolicyPolicyLastEntryRule: TypeAlias = Literal["allow", "default", "deny"]
UpdateOrganizationAdminOrgAccess: TypeAlias = Literal["enterprise", "full", "none", "read-only"]
UpdateOrganizationAlertsProfileType: TypeAlias = Literal[
    "appOutage",
    "voipJitter",
    "voipMos",
    "voipPacketLoss",
    "wanLatency",
    "wanPacketLoss",
    "wanStatus",
    "wanUtilization",
]
UpdateOrganizationConfigTemplateSwitchProfilePortAccessPolicyType: TypeAlias = Literal[
    "Custom access policy", "MAC allow list", "Open", "Sticky MAC allow list"
]
UpdateOrganizationConfigTemplateSwitchProfilePortStpGuard: TypeAlias = Literal[
    "bpdu guard", "disabled", "loop guard", "root guard"
]
UpdateOrganizationConfigTemplateSwitchProfilePortType: TypeAlias = Literal[
    "access", "dad", "routed", "stack", "svl", "trunk"
]
UpdateOrganizationConfigTemplateSwitchProfilePortUdld: TypeAlias = Literal["Alert only", "Enforce"]
UpdateOrganizationSmAdminsRoleScope: TypeAlias = Literal[
    "all_tags", "some", "without_all_tags", "without_some"
]
UpdateOrganizationSnmpV3AuthMode: TypeAlias = Literal["MD5", "SHA"]
UpdateOrganizationSnmpV3PrivMode: TypeAlias = Literal["AES128", "DES"]
VmxNetworkDevicesClaimSize: TypeAlias = Literal["100", "large", "medium", "small", "xlarge"]
